# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["CountryRuleParam", "Geo"]


class Geo(TypedDict, total=False):
    country_code: Required[str]
    """The country code that should be matched."""


class CountryRuleParam(TypedDict, total=False):
    """Matches a specific country"""

    geo: Required[Geo]
