# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Union, Optional
from typing_extensions import TypeAlias

__all__ = ["RegionGetResponse"]

RegionGetResponse: TypeAlias = Union[Optional[str], Optional[object]]
