# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["MeetingDeleteMeetingParticipantResponse", "Data"]


class Data(BaseModel):
    """Data returned by the operation"""

    created_at: datetime
    """Timestamp this object was created at. The time is returned in ISO format."""

    custom_participant_id: str
    """A unique participant ID generated by the client."""

    preset_id: str
    """ID of the preset applied to this participant."""

    updated_at: datetime
    """Timestamp this object was updated at. The time is returned in ISO format."""


class MeetingDeleteMeetingParticipantResponse(BaseModel):
    success: bool
    """Success status of the operation"""

    data: Optional[Data] = None
    """Data returned by the operation"""
