# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["MeetingGetMeetingParticipantsResponse", "Data", "Paging"]


class Data(BaseModel):
    """Represents a participant."""

    id: str
    """ID of the participant."""

    created_at: datetime
    """When this object was created. The time is returned in ISO format."""

    custom_participant_id: str
    """A unique participant ID generated by the client."""

    preset_name: str
    """Preset applied to the participant."""

    updated_at: datetime
    """When this object was updated. The time is returned in ISO format."""

    name: Optional[str] = None
    """Name of the participant."""

    picture: Optional[str] = None
    """URL to a picture of the participant."""


class Paging(BaseModel):
    end_offset: float

    start_offset: float

    total_count: float


class MeetingGetMeetingParticipantsResponse(BaseModel):
    data: List[Data]

    paging: Paging

    success: bool
