# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["CertificateEditParams"]


class CertificateEditParams(TypedDict, total=False):
    zone_id: Required[str]

    enabled: Required[bool]
    """
    The current status of the device policy certificate provisioning feature for
    WARP clients.
    """
