# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .page_rule import PageRule

__all__ = ["PageRuleListResponse"]

PageRuleListResponse: TypeAlias = List[PageRule]
