# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional
from typing_extensions import TypeAlias

__all__ = ["JsonCreateResponse"]

JsonCreateResponse: TypeAlias = Dict[str, Optional[object]]
