# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Union
from typing_extensions import TypeAlias

__all__ = ["RevokeCreateResponse"]

RevokeCreateResponse: TypeAlias = Union[str, object, None]
