# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ...._models import BaseModel

__all__ = ["RawEditResponse"]


class RawEditResponse(BaseModel):
    id: str

    data: object
