# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ...._models import BaseModel

__all__ = ["TailGetResponse"]


class TailGetResponse(BaseModel):
    id: str
    """Identifier."""

    expires_at: str

    url: str
