# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["LivestreamCreateIndependentLivestreamParams"]


class LivestreamCreateIndependentLivestreamParams(TypedDict, total=False):
    account_id: Required[str]
    """The account identifier tag."""

    name: Optional[str]
    """Name of the livestream"""
