# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["CustomTrustStoreCreateParams"]


class CustomTrustStoreCreateParams(TypedDict, total=False):
    zone_id: Required[str]
    """Identifier."""

    certificate: Required[str]
    """The root CA certificate in PEM format.

    Only root CA certificates are accepted; intermediate and leaf certificates are
    not supported.
    """
