# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["RecipientListParams"]


class RecipientListParams(TypedDict, total=False):
    account_id: Required[str]
    """Account identifier."""

    include_resources: bool
    """Include resources in the response."""

    page: int
    """Page number."""

    per_page: int
    """Number of objects to return per page."""
