# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .fallthrough_create_params import FallthroughCreateParams as FallthroughCreateParams
from .fallthrough_create_response import FallthroughCreateResponse as FallthroughCreateResponse
