# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["Status"]

Status: TypeAlias = Literal["active", "pending_reactivation", "pending_revocation", "revoked"]
