# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from ...._models import BaseModel

__all__ = ["TopupStatusResponse"]


class TopupStatusResponse(BaseModel):
    payment_intent_id: str

    status: Literal["completed", "pending"]
