# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["PoolListParams"]


class PoolListParams(TypedDict, total=False):
    account_id: Required[str]
    """Identifier."""

    monitor: str
    """
    The ID of the Monitor to use for checking the health of origins within this
    pool.
    """
