# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["CredentialEditParams"]


class CredentialEditParams(TypedDict, total=False):
    account_id: Required[str]
    """Identifier."""

    credential_set_id: Required[str]

    location: Literal["header", "cookie"]
    """Where the credential is attached in outgoing requests."""

    location_name: str
    """Name of the header or cookie where the credential is attached."""

    name: str
    """Human-readable name."""

    value: str
    """The credential value. Write-only. Never returned in responses."""
