# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import typing_extensions
from typing import Any, Optional, cast

import httpx

from ...._types import Body, Query, Headers, NotGiven, SequenceNotStr, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._wrappers import ResultWrapper
from ...._base_client import make_request_options
from ....types.zero_trust.devices.unrevoke_create_response import UnrevokeCreateResponse

__all__ = ["UnrevokeResource", "AsyncUnrevokeResource"]


class UnrevokeResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> UnrevokeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return UnrevokeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> UnrevokeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return UnrevokeResourceWithStreamingResponse(self)

    @typing_extensions.deprecated("deprecated")
    def create(
        self,
        *,
        account_id: str,
        body: SequenceNotStr[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[UnrevokeCreateResponse]:
        """Unrevokes a list of devices.

        Not supported when
        [multi-user mode](https://developers.cloudflare.com/cloudflare-one/connections/connect-devices/warp/deployment/mdm-deployment/windows-multiuser/)
        is enabled.

        **Deprecated**: please use POST
        /accounts/{account_id}/devices/registrations/unrevoke instead.

        Args:
          body: A list of Registration IDs to unrevoke.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return cast(
            Optional[UnrevokeCreateResponse],
            self._post(
                path_template("/accounts/{account_id}/devices/unrevoke", account_id=account_id),
                body=maybe_transform(body, SequenceNotStr[str]),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    post_parser=ResultWrapper[Optional[UnrevokeCreateResponse]]._unwrapper,
                ),
                cast_to=cast(
                    Any, ResultWrapper[UnrevokeCreateResponse]
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )


class AsyncUnrevokeResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncUnrevokeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncUnrevokeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncUnrevokeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncUnrevokeResourceWithStreamingResponse(self)

    @typing_extensions.deprecated("deprecated")
    async def create(
        self,
        *,
        account_id: str,
        body: SequenceNotStr[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[UnrevokeCreateResponse]:
        """Unrevokes a list of devices.

        Not supported when
        [multi-user mode](https://developers.cloudflare.com/cloudflare-one/connections/connect-devices/warp/deployment/mdm-deployment/windows-multiuser/)
        is enabled.

        **Deprecated**: please use POST
        /accounts/{account_id}/devices/registrations/unrevoke instead.

        Args:
          body: A list of Registration IDs to unrevoke.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return cast(
            Optional[UnrevokeCreateResponse],
            await self._post(
                path_template("/accounts/{account_id}/devices/unrevoke", account_id=account_id),
                body=await async_maybe_transform(body, SequenceNotStr[str]),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    post_parser=ResultWrapper[Optional[UnrevokeCreateResponse]]._unwrapper,
                ),
                cast_to=cast(
                    Any, ResultWrapper[UnrevokeCreateResponse]
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )


class UnrevokeResourceWithRawResponse:
    def __init__(self, unrevoke: UnrevokeResource) -> None:
        self._unrevoke = unrevoke

        self.create = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                unrevoke.create,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncUnrevokeResourceWithRawResponse:
    def __init__(self, unrevoke: AsyncUnrevokeResource) -> None:
        self._unrevoke = unrevoke

        self.create = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                unrevoke.create,  # pyright: ignore[reportDeprecated],
            )
        )


class UnrevokeResourceWithStreamingResponse:
    def __init__(self, unrevoke: UnrevokeResource) -> None:
        self._unrevoke = unrevoke

        self.create = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                unrevoke.create,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncUnrevokeResourceWithStreamingResponse:
    def __init__(self, unrevoke: AsyncUnrevokeResource) -> None:
        self._unrevoke = unrevoke

        self.create = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                unrevoke.create,  # pyright: ignore[reportDeprecated],
            )
        )
