# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import TypeAlias

__all__ = ["RequestTypesResponse"]

RequestTypesResponse: TypeAlias = str
