# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["InstanceCreateResponse"]


class InstanceCreateResponse(BaseModel):
    id: str

    status: Literal["queued", "running", "paused", "errored", "terminated", "complete", "waitingForPause", "waiting"]

    version_id: str

    workflow_id: str
