# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ......_models import BaseModel

__all__ = ["EntryDeleteResponse"]


class EntryDeleteResponse(BaseModel):
    id: str
    """Specify the identifier of the hostname."""
