# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import TypeAlias

__all__ = ["OutgoingStatus"]

OutgoingStatus: TypeAlias = Optional[str]
