# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Optional, cast
from typing_extensions import Literal, overload

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ...._utils import path_template, required_args, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._wrappers import ResultWrapper
from ...._base_client import make_request_options
from ....types.r2.buckets import Provider
from ....types.r2.super_slurper import connectivity_precheck_source_params, connectivity_precheck_target_params
from ....types.r2.buckets.provider import Provider
from ....types.r2.super_slurper.connectivity_precheck_source_response import ConnectivityPrecheckSourceResponse
from ....types.r2.super_slurper.connectivity_precheck_target_response import ConnectivityPrecheckTargetResponse

__all__ = ["ConnectivityPrecheckResource", "AsyncConnectivityPrecheckResource"]


class ConnectivityPrecheckResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ConnectivityPrecheckResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return ConnectivityPrecheckResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ConnectivityPrecheckResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return ConnectivityPrecheckResourceWithStreamingResponse(self)

    @overload
    def source(
        self,
        *,
        account_id: str,
        bucket: str,
        secret: connectivity_precheck_source_params.R2SlurperS3SourceSchemaSecret,
        vendor: Literal["s3"],
        endpoint: Optional[str] | Omit = omit,
        keys: Optional[SequenceNotStr[str]] | Omit = omit,
        path_prefix: Optional[str] | Omit = omit,
        region: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ConnectivityPrecheckSourceResponse]:
        """
        Check whether tokens are valid against the source bucket

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def source(
        self,
        *,
        account_id: str,
        bucket: str,
        secret: connectivity_precheck_source_params.R2SlurperGcsSourceSchemaSecret,
        vendor: Literal["gcs"],
        keys: Optional[SequenceNotStr[str]] | Omit = omit,
        path_prefix: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ConnectivityPrecheckSourceResponse]:
        """
        Check whether tokens are valid against the source bucket

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def source(
        self,
        *,
        account_id: str,
        bucket: str,
        secret: connectivity_precheck_source_params.R2SlurperR2SourceSchemaSecret,
        vendor: Provider,
        jurisdiction: Literal["default", "eu", "fedramp"] | Omit = omit,
        keys: Optional[SequenceNotStr[str]] | Omit = omit,
        path_prefix: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ConnectivityPrecheckSourceResponse]:
        """
        Check whether tokens are valid against the source bucket

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["account_id", "bucket", "secret", "vendor"])
    def source(
        self,
        *,
        account_id: str,
        bucket: str,
        secret: connectivity_precheck_source_params.R2SlurperS3SourceSchemaSecret
        | connectivity_precheck_source_params.R2SlurperGcsSourceSchemaSecret
        | connectivity_precheck_source_params.R2SlurperR2SourceSchemaSecret,
        vendor: Literal["s3"] | Literal["gcs"] | Provider,
        endpoint: Optional[str] | Omit = omit,
        keys: Optional[SequenceNotStr[str]] | Omit = omit,
        path_prefix: Optional[str] | Omit = omit,
        region: Optional[str] | Omit = omit,
        jurisdiction: Literal["default", "eu", "fedramp"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ConnectivityPrecheckSourceResponse]:
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._put(
            path_template("/accounts/{account_id}/slurper/source/connectivity-precheck", account_id=account_id),
            body=maybe_transform(
                {
                    "bucket": bucket,
                    "secret": secret,
                    "vendor": vendor,
                    "endpoint": endpoint,
                    "keys": keys,
                    "path_prefix": path_prefix,
                    "region": region,
                    "jurisdiction": jurisdiction,
                },
                connectivity_precheck_source_params.ConnectivityPrecheckSourceParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[ConnectivityPrecheckSourceResponse]]._unwrapper,
            ),
            cast_to=cast(
                Type[Optional[ConnectivityPrecheckSourceResponse]], ResultWrapper[ConnectivityPrecheckSourceResponse]
            ),
        )

    def target(
        self,
        *,
        account_id: str,
        bucket: str,
        secret: connectivity_precheck_target_params.Secret,
        vendor: Provider,
        jurisdiction: Literal["default", "eu", "fedramp"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ConnectivityPrecheckTargetResponse]:
        """
        Check whether tokens are valid against the target bucket

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._put(
            path_template("/accounts/{account_id}/slurper/target/connectivity-precheck", account_id=account_id),
            body=maybe_transform(
                {
                    "bucket": bucket,
                    "secret": secret,
                    "vendor": vendor,
                    "jurisdiction": jurisdiction,
                },
                connectivity_precheck_target_params.ConnectivityPrecheckTargetParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[ConnectivityPrecheckTargetResponse]]._unwrapper,
            ),
            cast_to=cast(
                Type[Optional[ConnectivityPrecheckTargetResponse]], ResultWrapper[ConnectivityPrecheckTargetResponse]
            ),
        )


class AsyncConnectivityPrecheckResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncConnectivityPrecheckResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncConnectivityPrecheckResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncConnectivityPrecheckResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncConnectivityPrecheckResourceWithStreamingResponse(self)

    @overload
    async def source(
        self,
        *,
        account_id: str,
        bucket: str,
        secret: connectivity_precheck_source_params.R2SlurperS3SourceSchemaSecret,
        vendor: Literal["s3"],
        endpoint: Optional[str] | Omit = omit,
        keys: Optional[SequenceNotStr[str]] | Omit = omit,
        path_prefix: Optional[str] | Omit = omit,
        region: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ConnectivityPrecheckSourceResponse]:
        """
        Check whether tokens are valid against the source bucket

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def source(
        self,
        *,
        account_id: str,
        bucket: str,
        secret: connectivity_precheck_source_params.R2SlurperGcsSourceSchemaSecret,
        vendor: Literal["gcs"],
        keys: Optional[SequenceNotStr[str]] | Omit = omit,
        path_prefix: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ConnectivityPrecheckSourceResponse]:
        """
        Check whether tokens are valid against the source bucket

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def source(
        self,
        *,
        account_id: str,
        bucket: str,
        secret: connectivity_precheck_source_params.R2SlurperR2SourceSchemaSecret,
        vendor: Provider,
        jurisdiction: Literal["default", "eu", "fedramp"] | Omit = omit,
        keys: Optional[SequenceNotStr[str]] | Omit = omit,
        path_prefix: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ConnectivityPrecheckSourceResponse]:
        """
        Check whether tokens are valid against the source bucket

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["account_id", "bucket", "secret", "vendor"])
    async def source(
        self,
        *,
        account_id: str,
        bucket: str,
        secret: connectivity_precheck_source_params.R2SlurperS3SourceSchemaSecret
        | connectivity_precheck_source_params.R2SlurperGcsSourceSchemaSecret
        | connectivity_precheck_source_params.R2SlurperR2SourceSchemaSecret,
        vendor: Literal["s3"] | Literal["gcs"] | Provider,
        endpoint: Optional[str] | Omit = omit,
        keys: Optional[SequenceNotStr[str]] | Omit = omit,
        path_prefix: Optional[str] | Omit = omit,
        region: Optional[str] | Omit = omit,
        jurisdiction: Literal["default", "eu", "fedramp"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ConnectivityPrecheckSourceResponse]:
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._put(
            path_template("/accounts/{account_id}/slurper/source/connectivity-precheck", account_id=account_id),
            body=await async_maybe_transform(
                {
                    "bucket": bucket,
                    "secret": secret,
                    "vendor": vendor,
                    "endpoint": endpoint,
                    "keys": keys,
                    "path_prefix": path_prefix,
                    "region": region,
                    "jurisdiction": jurisdiction,
                },
                connectivity_precheck_source_params.ConnectivityPrecheckSourceParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[ConnectivityPrecheckSourceResponse]]._unwrapper,
            ),
            cast_to=cast(
                Type[Optional[ConnectivityPrecheckSourceResponse]], ResultWrapper[ConnectivityPrecheckSourceResponse]
            ),
        )

    async def target(
        self,
        *,
        account_id: str,
        bucket: str,
        secret: connectivity_precheck_target_params.Secret,
        vendor: Provider,
        jurisdiction: Literal["default", "eu", "fedramp"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[ConnectivityPrecheckTargetResponse]:
        """
        Check whether tokens are valid against the target bucket

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._put(
            path_template("/accounts/{account_id}/slurper/target/connectivity-precheck", account_id=account_id),
            body=await async_maybe_transform(
                {
                    "bucket": bucket,
                    "secret": secret,
                    "vendor": vendor,
                    "jurisdiction": jurisdiction,
                },
                connectivity_precheck_target_params.ConnectivityPrecheckTargetParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[ConnectivityPrecheckTargetResponse]]._unwrapper,
            ),
            cast_to=cast(
                Type[Optional[ConnectivityPrecheckTargetResponse]], ResultWrapper[ConnectivityPrecheckTargetResponse]
            ),
        )


class ConnectivityPrecheckResourceWithRawResponse:
    def __init__(self, connectivity_precheck: ConnectivityPrecheckResource) -> None:
        self._connectivity_precheck = connectivity_precheck

        self.source = to_raw_response_wrapper(
            connectivity_precheck.source,
        )
        self.target = to_raw_response_wrapper(
            connectivity_precheck.target,
        )


class AsyncConnectivityPrecheckResourceWithRawResponse:
    def __init__(self, connectivity_precheck: AsyncConnectivityPrecheckResource) -> None:
        self._connectivity_precheck = connectivity_precheck

        self.source = async_to_raw_response_wrapper(
            connectivity_precheck.source,
        )
        self.target = async_to_raw_response_wrapper(
            connectivity_precheck.target,
        )


class ConnectivityPrecheckResourceWithStreamingResponse:
    def __init__(self, connectivity_precheck: ConnectivityPrecheckResource) -> None:
        self._connectivity_precheck = connectivity_precheck

        self.source = to_streamed_response_wrapper(
            connectivity_precheck.source,
        )
        self.target = to_streamed_response_wrapper(
            connectivity_precheck.target,
        )


class AsyncConnectivityPrecheckResourceWithStreamingResponse:
    def __init__(self, connectivity_precheck: AsyncConnectivityPrecheckResource) -> None:
        self._connectivity_precheck = connectivity_precheck

        self.source = async_to_streamed_response_wrapper(
            connectivity_precheck.source,
        )
        self.target = async_to_streamed_response_wrapper(
            connectivity_precheck.target,
        )
