# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, cast
from typing_extensions import Literal

import httpx

from ..._types import Body, Query, Headers, NotGiven, not_given
from ..._utils import path_template, maybe_transform, async_maybe_transform
from .payloads import (
    PayloadsResource,
    AsyncPayloadsResource,
    PayloadsResourceWithRawResponse,
    AsyncPayloadsResourceWithRawResponse,
    PayloadsResourceWithStreamingResponse,
    AsyncPayloadsResourceWithStreamingResponse,
)
from .settings import (
    SettingsResource,
    AsyncSettingsResource,
    SettingsResourceWithRawResponse,
    AsyncSettingsResourceWithRawResponse,
    SettingsResourceWithStreamingResponse,
    AsyncSettingsResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._wrappers import ResultWrapper
from ..._base_client import make_request_options
from ...types.content_scanning import content_scanning_create_params, content_scanning_update_params
from ...types.content_scanning.content_scanning_get_response import ContentScanningGetResponse
from ...types.content_scanning.content_scanning_create_response import ContentScanningCreateResponse
from ...types.content_scanning.content_scanning_update_response import ContentScanningUpdateResponse

__all__ = ["ContentScanningResource", "AsyncContentScanningResource"]


class ContentScanningResource(SyncAPIResource):
    @cached_property
    def payloads(self) -> PayloadsResource:
        return PayloadsResource(self._client)

    @cached_property
    def settings(self) -> SettingsResource:
        return SettingsResource(self._client)

    @cached_property
    def with_raw_response(self) -> ContentScanningResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return ContentScanningResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ContentScanningResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return ContentScanningResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        zone_id: str,
        value: Literal["enabled", "disabled"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ContentScanningCreateResponse:
        """
        Update the Content Scanning status.

        Args:
          zone_id: Defines an identifier.

          value: The status value for Content Scanning.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._put(
            path_template("/zones/{zone_id}/content-upload-scan/settings", zone_id=zone_id),
            body=maybe_transform({"value": value}, content_scanning_create_params.ContentScanningCreateParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[ContentScanningCreateResponse]._unwrapper,
            ),
            cast_to=cast(Type[ContentScanningCreateResponse], ResultWrapper[ContentScanningCreateResponse]),
        )

    def update(
        self,
        *,
        zone_id: str,
        value: Literal["enabled", "disabled"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ContentScanningUpdateResponse:
        """
        Update the Content Scanning status.

        Args:
          zone_id: Defines an identifier.

          value: The status value for Content Scanning.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._put(
            path_template("/zones/{zone_id}/content-upload-scan/settings", zone_id=zone_id),
            body=maybe_transform({"value": value}, content_scanning_update_params.ContentScanningUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[ContentScanningUpdateResponse]._unwrapper,
            ),
            cast_to=cast(Type[ContentScanningUpdateResponse], ResultWrapper[ContentScanningUpdateResponse]),
        )

    def disable(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Disable Content Scanning.

        Args:
          zone_id: Defines an identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._post(
            path_template("/zones/{zone_id}/content-upload-scan/disable", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[object]._unwrapper,
            ),
            cast_to=cast(Type[object], ResultWrapper[object]),
        )

    def enable(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Enable Content Scanning.

        Args:
          zone_id: Defines an identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._post(
            path_template("/zones/{zone_id}/content-upload-scan/enable", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[object]._unwrapper,
            ),
            cast_to=cast(Type[object], ResultWrapper[object]),
        )

    def get(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ContentScanningGetResponse:
        """
        Retrieve the current status of Content Scanning.

        Args:
          zone_id: Defines an identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get(
            path_template("/zones/{zone_id}/content-upload-scan/settings", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[ContentScanningGetResponse]._unwrapper,
            ),
            cast_to=cast(Type[ContentScanningGetResponse], ResultWrapper[ContentScanningGetResponse]),
        )


class AsyncContentScanningResource(AsyncAPIResource):
    @cached_property
    def payloads(self) -> AsyncPayloadsResource:
        return AsyncPayloadsResource(self._client)

    @cached_property
    def settings(self) -> AsyncSettingsResource:
        return AsyncSettingsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncContentScanningResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncContentScanningResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncContentScanningResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncContentScanningResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        zone_id: str,
        value: Literal["enabled", "disabled"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ContentScanningCreateResponse:
        """
        Update the Content Scanning status.

        Args:
          zone_id: Defines an identifier.

          value: The status value for Content Scanning.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._put(
            path_template("/zones/{zone_id}/content-upload-scan/settings", zone_id=zone_id),
            body=await async_maybe_transform(
                {"value": value}, content_scanning_create_params.ContentScanningCreateParams
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[ContentScanningCreateResponse]._unwrapper,
            ),
            cast_to=cast(Type[ContentScanningCreateResponse], ResultWrapper[ContentScanningCreateResponse]),
        )

    async def update(
        self,
        *,
        zone_id: str,
        value: Literal["enabled", "disabled"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ContentScanningUpdateResponse:
        """
        Update the Content Scanning status.

        Args:
          zone_id: Defines an identifier.

          value: The status value for Content Scanning.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._put(
            path_template("/zones/{zone_id}/content-upload-scan/settings", zone_id=zone_id),
            body=await async_maybe_transform(
                {"value": value}, content_scanning_update_params.ContentScanningUpdateParams
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[ContentScanningUpdateResponse]._unwrapper,
            ),
            cast_to=cast(Type[ContentScanningUpdateResponse], ResultWrapper[ContentScanningUpdateResponse]),
        )

    async def disable(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Disable Content Scanning.

        Args:
          zone_id: Defines an identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._post(
            path_template("/zones/{zone_id}/content-upload-scan/disable", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[object]._unwrapper,
            ),
            cast_to=cast(Type[object], ResultWrapper[object]),
        )

    async def enable(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Enable Content Scanning.

        Args:
          zone_id: Defines an identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._post(
            path_template("/zones/{zone_id}/content-upload-scan/enable", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[object]._unwrapper,
            ),
            cast_to=cast(Type[object], ResultWrapper[object]),
        )

    async def get(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ContentScanningGetResponse:
        """
        Retrieve the current status of Content Scanning.

        Args:
          zone_id: Defines an identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._get(
            path_template("/zones/{zone_id}/content-upload-scan/settings", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[ContentScanningGetResponse]._unwrapper,
            ),
            cast_to=cast(Type[ContentScanningGetResponse], ResultWrapper[ContentScanningGetResponse]),
        )


class ContentScanningResourceWithRawResponse:
    def __init__(self, content_scanning: ContentScanningResource) -> None:
        self._content_scanning = content_scanning

        self.create = to_raw_response_wrapper(
            content_scanning.create,
        )
        self.update = to_raw_response_wrapper(
            content_scanning.update,
        )
        self.disable = to_raw_response_wrapper(
            content_scanning.disable,
        )
        self.enable = to_raw_response_wrapper(
            content_scanning.enable,
        )
        self.get = to_raw_response_wrapper(
            content_scanning.get,
        )

    @cached_property
    def payloads(self) -> PayloadsResourceWithRawResponse:
        return PayloadsResourceWithRawResponse(self._content_scanning.payloads)

    @cached_property
    def settings(self) -> SettingsResourceWithRawResponse:
        return SettingsResourceWithRawResponse(self._content_scanning.settings)


class AsyncContentScanningResourceWithRawResponse:
    def __init__(self, content_scanning: AsyncContentScanningResource) -> None:
        self._content_scanning = content_scanning

        self.create = async_to_raw_response_wrapper(
            content_scanning.create,
        )
        self.update = async_to_raw_response_wrapper(
            content_scanning.update,
        )
        self.disable = async_to_raw_response_wrapper(
            content_scanning.disable,
        )
        self.enable = async_to_raw_response_wrapper(
            content_scanning.enable,
        )
        self.get = async_to_raw_response_wrapper(
            content_scanning.get,
        )

    @cached_property
    def payloads(self) -> AsyncPayloadsResourceWithRawResponse:
        return AsyncPayloadsResourceWithRawResponse(self._content_scanning.payloads)

    @cached_property
    def settings(self) -> AsyncSettingsResourceWithRawResponse:
        return AsyncSettingsResourceWithRawResponse(self._content_scanning.settings)


class ContentScanningResourceWithStreamingResponse:
    def __init__(self, content_scanning: ContentScanningResource) -> None:
        self._content_scanning = content_scanning

        self.create = to_streamed_response_wrapper(
            content_scanning.create,
        )
        self.update = to_streamed_response_wrapper(
            content_scanning.update,
        )
        self.disable = to_streamed_response_wrapper(
            content_scanning.disable,
        )
        self.enable = to_streamed_response_wrapper(
            content_scanning.enable,
        )
        self.get = to_streamed_response_wrapper(
            content_scanning.get,
        )

    @cached_property
    def payloads(self) -> PayloadsResourceWithStreamingResponse:
        return PayloadsResourceWithStreamingResponse(self._content_scanning.payloads)

    @cached_property
    def settings(self) -> SettingsResourceWithStreamingResponse:
        return SettingsResourceWithStreamingResponse(self._content_scanning.settings)


class AsyncContentScanningResourceWithStreamingResponse:
    def __init__(self, content_scanning: AsyncContentScanningResource) -> None:
        self._content_scanning = content_scanning

        self.create = async_to_streamed_response_wrapper(
            content_scanning.create,
        )
        self.update = async_to_streamed_response_wrapper(
            content_scanning.update,
        )
        self.disable = async_to_streamed_response_wrapper(
            content_scanning.disable,
        )
        self.enable = async_to_streamed_response_wrapper(
            content_scanning.enable,
        )
        self.get = async_to_streamed_response_wrapper(
            content_scanning.get,
        )

    @cached_property
    def payloads(self) -> AsyncPayloadsResourceWithStreamingResponse:
        return AsyncPayloadsResourceWithStreamingResponse(self._content_scanning.payloads)

    @cached_property
    def settings(self) -> AsyncSettingsResourceWithStreamingResponse:
        return AsyncSettingsResourceWithStreamingResponse(self._content_scanning.settings)
