# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Union, cast
from datetime import datetime
from typing_extensions import Literal

import httpx

from .outages import (
    OutagesResource,
    AsyncOutagesResource,
    OutagesResourceWithRawResponse,
    AsyncOutagesResourceWithRawResponse,
    OutagesResourceWithStreamingResponse,
    AsyncOutagesResourceWithStreamingResponse,
)
from ...._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._wrappers import ResultWrapper
from ....types.radar import annotation_list_params
from ...._base_client import make_request_options
from ....types.radar.annotation_list_response import AnnotationListResponse

__all__ = ["AnnotationsResource", "AsyncAnnotationsResource"]


class AnnotationsResource(SyncAPIResource):
    @cached_property
    def outages(self) -> OutagesResource:
        return OutagesResource(self._client)

    @cached_property
    def with_raw_response(self) -> AnnotationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AnnotationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AnnotationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AnnotationsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        asn: int | Omit = omit,
        data_source: Literal[
            "ALL",
            "AI_BOTS",
            "AI_GATEWAY",
            "BGP",
            "BOTS",
            "CONNECTION_ANOMALY",
            "CT",
            "DNS",
            "DNS_MAGNITUDE",
            "DNS_AS112",
            "DOS",
            "EMAIL_ROUTING",
            "EMAIL_SECURITY",
            "FW",
            "FW_PG",
            "HTTP",
            "HTTP_CONTROL",
            "HTTP_CRAWLER_REFERER",
            "HTTP_ORIGINS",
            "IQI",
            "LEAKED_CREDENTIALS",
            "NET",
            "ROBOTS_TXT",
            "SPEED",
            "WORKERS_AI",
        ]
        | Omit = omit,
        date_end: Union[str, datetime] | Omit = omit,
        date_range: str | Omit = omit,
        date_start: Union[str, datetime] | Omit = omit,
        event_type: Literal["EVENT", "GENERAL", "OUTAGE", "PARTIAL_PROJECTION", "PIPELINE", "TRAFFIC_ANOMALY"]
        | Omit = omit,
        format: Literal["JSON", "CSV"] | Omit = omit,
        limit: int | Omit = omit,
        location: str | Omit = omit,
        offset: int | Omit = omit,
        origin: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AnnotationListResponse:
        """
        Retrieves the latest annotations.

        Args:
          asn: Filters results by Autonomous System. Specify a single Autonomous System Number
              (ASN) as integer.

          data_source: Filters results by data source.

          date_end: End of the date range (inclusive).

          date_range: Filters results by date range.

          date_start: Start of the date range (inclusive).

          event_type: Filters results by event type.

          format: Format in which results will be returned.

          limit: Limits the number of objects returned in the response.

          location: Filters results by location. Specify an alpha-2 location code.

          offset: Skips the specified number of objects before fetching the results.

          origin: Filters results by origin.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/radar/annotations",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "asn": asn,
                        "data_source": data_source,
                        "date_end": date_end,
                        "date_range": date_range,
                        "date_start": date_start,
                        "event_type": event_type,
                        "format": format,
                        "limit": limit,
                        "location": location,
                        "offset": offset,
                        "origin": origin,
                    },
                    annotation_list_params.AnnotationListParams,
                ),
                post_parser=ResultWrapper[AnnotationListResponse]._unwrapper,
            ),
            cast_to=cast(Type[AnnotationListResponse], ResultWrapper[AnnotationListResponse]),
        )


class AsyncAnnotationsResource(AsyncAPIResource):
    @cached_property
    def outages(self) -> AsyncOutagesResource:
        return AsyncOutagesResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncAnnotationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAnnotationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAnnotationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncAnnotationsResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        asn: int | Omit = omit,
        data_source: Literal[
            "ALL",
            "AI_BOTS",
            "AI_GATEWAY",
            "BGP",
            "BOTS",
            "CONNECTION_ANOMALY",
            "CT",
            "DNS",
            "DNS_MAGNITUDE",
            "DNS_AS112",
            "DOS",
            "EMAIL_ROUTING",
            "EMAIL_SECURITY",
            "FW",
            "FW_PG",
            "HTTP",
            "HTTP_CONTROL",
            "HTTP_CRAWLER_REFERER",
            "HTTP_ORIGINS",
            "IQI",
            "LEAKED_CREDENTIALS",
            "NET",
            "ROBOTS_TXT",
            "SPEED",
            "WORKERS_AI",
        ]
        | Omit = omit,
        date_end: Union[str, datetime] | Omit = omit,
        date_range: str | Omit = omit,
        date_start: Union[str, datetime] | Omit = omit,
        event_type: Literal["EVENT", "GENERAL", "OUTAGE", "PARTIAL_PROJECTION", "PIPELINE", "TRAFFIC_ANOMALY"]
        | Omit = omit,
        format: Literal["JSON", "CSV"] | Omit = omit,
        limit: int | Omit = omit,
        location: str | Omit = omit,
        offset: int | Omit = omit,
        origin: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AnnotationListResponse:
        """
        Retrieves the latest annotations.

        Args:
          asn: Filters results by Autonomous System. Specify a single Autonomous System Number
              (ASN) as integer.

          data_source: Filters results by data source.

          date_end: End of the date range (inclusive).

          date_range: Filters results by date range.

          date_start: Start of the date range (inclusive).

          event_type: Filters results by event type.

          format: Format in which results will be returned.

          limit: Limits the number of objects returned in the response.

          location: Filters results by location. Specify an alpha-2 location code.

          offset: Skips the specified number of objects before fetching the results.

          origin: Filters results by origin.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/radar/annotations",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "asn": asn,
                        "data_source": data_source,
                        "date_end": date_end,
                        "date_range": date_range,
                        "date_start": date_start,
                        "event_type": event_type,
                        "format": format,
                        "limit": limit,
                        "location": location,
                        "offset": offset,
                        "origin": origin,
                    },
                    annotation_list_params.AnnotationListParams,
                ),
                post_parser=ResultWrapper[AnnotationListResponse]._unwrapper,
            ),
            cast_to=cast(Type[AnnotationListResponse], ResultWrapper[AnnotationListResponse]),
        )


class AnnotationsResourceWithRawResponse:
    def __init__(self, annotations: AnnotationsResource) -> None:
        self._annotations = annotations

        self.list = to_raw_response_wrapper(
            annotations.list,
        )

    @cached_property
    def outages(self) -> OutagesResourceWithRawResponse:
        return OutagesResourceWithRawResponse(self._annotations.outages)


class AsyncAnnotationsResourceWithRawResponse:
    def __init__(self, annotations: AsyncAnnotationsResource) -> None:
        self._annotations = annotations

        self.list = async_to_raw_response_wrapper(
            annotations.list,
        )

    @cached_property
    def outages(self) -> AsyncOutagesResourceWithRawResponse:
        return AsyncOutagesResourceWithRawResponse(self._annotations.outages)


class AnnotationsResourceWithStreamingResponse:
    def __init__(self, annotations: AnnotationsResource) -> None:
        self._annotations = annotations

        self.list = to_streamed_response_wrapper(
            annotations.list,
        )

    @cached_property
    def outages(self) -> OutagesResourceWithStreamingResponse:
        return OutagesResourceWithStreamingResponse(self._annotations.outages)


class AsyncAnnotationsResourceWithStreamingResponse:
    def __init__(self, annotations: AsyncAnnotationsResource) -> None:
        self._annotations = annotations

        self.list = async_to_streamed_response_wrapper(
            annotations.list,
        )

    @cached_property
    def outages(self) -> AsyncOutagesResourceWithStreamingResponse:
        return AsyncOutagesResourceWithStreamingResponse(self._annotations.outages)
