# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["CredentialSetEditResponse"]


class CredentialSetEditResponse(BaseModel):
    id: str
    """Credential set identifier."""

    name: str
    """Human-readable name."""
