# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["AlwaysUseHTTPS"]


class AlwaysUseHTTPS(BaseModel):
    id: Optional[Literal["always_use_https"]] = None
    """
    If enabled, any ` http://`` URL is converted to  `https://` through a 301
    redirect.
    """
