# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .verification import Verification

__all__ = ["VerificationGetResponse"]

VerificationGetResponse: TypeAlias = List[Verification]
