# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["IPRuleParam", "IP"]


class IP(TypedDict, total=False):
    ip: Required[str]
    """An IPv4 or IPv6 CIDR block."""


class IPRuleParam(TypedDict, total=False):
    """Matches an IP address block."""

    ip: Required[IP]
