# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .ttl import TTL as TTL
from .dnssec import DNSSEC as DNSSEC
from .a_record import ARecord as ARecord
from .ds_record import DSRecord as DSRecord
from .mx_record import MXRecord as MXRecord
from .ns_record import NSRecord as NSRecord
from .ttl_param import TTLParam as TTLParam
from .caa_record import CAARecord as CAARecord
from .loc_record import LOCRecord as LOCRecord
from .ptr_record import PTRRecord as PTRRecord
from .srv_record import SRVRecord as SRVRecord
from .txt_record import TXTRecord as TXTRecord
from .uri_record import URIRecord as URIRecord
from .aaaa_record import AAAARecord as AAAARecord
from .cert_record import CERTRecord as CERTRecord
from .record_tags import RecordTags as RecordTags
from .svcb_record import SVCBRecord as SVCBRecord
from .tlsa_record import TLSARecord as TLSARecord
from .cname_record import CNAMERecord as CNAMERecord
from .https_record import HTTPSRecord as HTTPSRecord
from .naptr_record import NAPTRRecord as NAPTRRecord
from .sshfp_record import SSHFPRecord as SSHFPRecord
from .dnskey_record import DNSKEYRecord as DNSKEYRecord
from .smimea_record import SMIMEARecord as SMIMEARecord
from .a_record_param import ARecordParam as ARecordParam
from .batch_put_param import BatchPutParam as BatchPutParam
from .ds_record_param import DSRecordParam as DSRecordParam
from .mx_record_param import MXRecordParam as MXRecordParam
from .ns_record_param import NSRecordParam as NSRecordParam
from .record_response import RecordResponse as RecordResponse
from .caa_record_param import CAARecordParam as CAARecordParam
from .loc_record_param import LOCRecordParam as LOCRecordParam
from .ptr_record_param import PTRRecordParam as PTRRecordParam
from .srv_record_param import SRVRecordParam as SRVRecordParam
from .txt_record_param import TXTRecordParam as TXTRecordParam
from .uri_record_param import URIRecordParam as URIRecordParam
from .aaaa_record_param import AAAARecordParam as AAAARecordParam
from .batch_patch_param import BatchPatchParam as BatchPatchParam
from .cert_record_param import CERTRecordParam as CERTRecordParam
from .svcb_record_param import SVCBRecordParam as SVCBRecordParam
from .tlsa_record_param import TLSARecordParam as TLSARecordParam
from .cname_record_param import CNAMERecordParam as CNAMERecordParam
from .dnssec_edit_params import DNSSECEditParams as DNSSECEditParams
from .https_record_param import HTTPSRecordParam as HTTPSRecordParam
from .naptr_record_param import NAPTRRecordParam as NAPTRRecordParam
from .record_edit_params import RecordEditParams as RecordEditParams
from .record_list_params import RecordListParams as RecordListParams
from .record_scan_params import RecordScanParams as RecordScanParams
from .sshfp_record_param import SSHFPRecordParam as SSHFPRecordParam
from .dnskey_record_param import DNSKEYRecordParam as DNSKEYRecordParam
from .record_batch_params import RecordBatchParams as RecordBatchParams
from .smimea_record_param import SMIMEARecordParam as SMIMEARecordParam
from .record_create_params import RecordCreateParams as RecordCreateParams
from .record_import_params import RecordImportParams as RecordImportParams
from .record_scan_response import RecordScanResponse as RecordScanResponse
from .record_update_params import RecordUpdateParams as RecordUpdateParams
from .record_batch_response import RecordBatchResponse as RecordBatchResponse
from .dnssec_delete_response import DNSSECDeleteResponse as DNSSECDeleteResponse
from .record_delete_response import RecordDeleteResponse as RecordDeleteResponse
from .record_export_response import RecordExportResponse as RecordExportResponse
from .record_import_response import RecordImportResponse as RecordImportResponse
from .record_scan_review_params import RecordScanReviewParams as RecordScanReviewParams
from .record_scan_review_response import RecordScanReviewResponse as RecordScanReviewResponse
from .record_scan_trigger_response import RecordScanTriggerResponse as RecordScanTriggerResponse
