# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["Stage"]


class Stage(BaseModel):
    """The status of the deployment."""

    ended_on: Optional[datetime] = None
    """When the stage ended."""

    name: Literal["queued", "initialize", "clone_repo", "build", "deploy"]
    """The current build stage."""

    started_on: Optional[datetime] = None
    """When the stage started."""

    status: Literal["success", "idle", "active", "failure", "canceled"]
    """State of the current stage."""
