# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .r2 import (
    R2Resource,
    AsyncR2Resource,
    R2ResourceWithRawResponse,
    AsyncR2ResourceWithRawResponse,
    R2ResourceWithStreamingResponse,
    AsyncR2ResourceWithStreamingResponse,
)
from .buckets import (
    BucketsResource,
    AsyncBucketsResource,
    BucketsResourceWithRawResponse,
    AsyncBucketsResourceWithRawResponse,
    BucketsResourceWithStreamingResponse,
    AsyncBucketsResourceWithStreamingResponse,
)
from .super_slurper import (
    SuperSlurperResource,
    AsyncSuperSlurperResource,
    SuperSlurperResourceWithRawResponse,
    AsyncSuperSlurperResourceWithRawResponse,
    SuperSlurperResourceWithStreamingResponse,
    AsyncSuperSlurperResourceWithStreamingResponse,
)
from .temporary_credentials import (
    TemporaryCredentialsResource,
    AsyncTemporaryCredentialsResource,
    TemporaryCredentialsResourceWithRawResponse,
    AsyncTemporaryCredentialsResourceWithRawResponse,
    TemporaryCredentialsResourceWithStreamingResponse,
    AsyncTemporaryCredentialsResourceWithStreamingResponse,
)

__all__ = [
    "BucketsResource",
    "AsyncBucketsResource",
    "BucketsResourceWithRawResponse",
    "AsyncBucketsResourceWithRawResponse",
    "BucketsResourceWithStreamingResponse",
    "AsyncBucketsResourceWithStreamingResponse",
    "TemporaryCredentialsResource",
    "AsyncTemporaryCredentialsResource",
    "TemporaryCredentialsResourceWithRawResponse",
    "AsyncTemporaryCredentialsResourceWithRawResponse",
    "TemporaryCredentialsResourceWithStreamingResponse",
    "AsyncTemporaryCredentialsResourceWithStreamingResponse",
    "SuperSlurperResource",
    "AsyncSuperSlurperResource",
    "SuperSlurperResourceWithRawResponse",
    "AsyncSuperSlurperResourceWithRawResponse",
    "SuperSlurperResourceWithStreamingResponse",
    "AsyncSuperSlurperResourceWithStreamingResponse",
    "R2Resource",
    "AsyncR2Resource",
    "R2ResourceWithRawResponse",
    "AsyncR2ResourceWithRawResponse",
    "R2ResourceWithStreamingResponse",
    "AsyncR2ResourceWithStreamingResponse",
]
