# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

from ..._models import BaseModel

__all__ = ["TraceCreateResponse"]


class TraceCreateResponse(BaseModel):
    """Trace result with an origin status code"""

    status_code: Optional[int] = None
    """HTTP Status code of zone response"""

    trace: Optional["Trace"] = None


from .trace import Trace
