# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import typing_extensions
from typing import Union
from datetime import datetime
from typing_extensions import Literal

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ...._utils import maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....pagination import SyncV4PagePaginationArray, AsyncV4PagePaginationArray
from ...._base_client import AsyncPaginator, make_request_options
from ....types.user.billing import history_list_params
from ....types.user.billing.billing_history import BillingHistory

__all__ = ["HistoryResource", "AsyncHistoryResource"]


class HistoryResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> HistoryResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return HistoryResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> HistoryResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return HistoryResourceWithStreamingResponse(self)

    @typing_extensions.deprecated("deprecated")
    def list(
        self,
        *,
        action: str | Omit = omit,
        occurred_at: Union[str, datetime] | Omit = omit,
        order: Literal["type", "occurred_at", "action"] | Omit = omit,
        page: float | Omit = omit,
        per_page: float | Omit = omit,
        type: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncV4PagePaginationArray[BillingHistory]:
        """
        Accesses your billing history object.

        Args:
          action: The billing item action.

          occurred_at: When the billing item was created.

          order: Field to order billing history by.

          page: Page number of paginated results.

          per_page: Number of items per page.

          type: The billing item type.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/user/billing/history",
            page=SyncV4PagePaginationArray[BillingHistory],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "action": action,
                        "occurred_at": occurred_at,
                        "order": order,
                        "page": page,
                        "per_page": per_page,
                        "type": type,
                    },
                    history_list_params.HistoryListParams,
                ),
            ),
            model=BillingHistory,
        )


class AsyncHistoryResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncHistoryResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncHistoryResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncHistoryResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncHistoryResourceWithStreamingResponse(self)

    @typing_extensions.deprecated("deprecated")
    def list(
        self,
        *,
        action: str | Omit = omit,
        occurred_at: Union[str, datetime] | Omit = omit,
        order: Literal["type", "occurred_at", "action"] | Omit = omit,
        page: float | Omit = omit,
        per_page: float | Omit = omit,
        type: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[BillingHistory, AsyncV4PagePaginationArray[BillingHistory]]:
        """
        Accesses your billing history object.

        Args:
          action: The billing item action.

          occurred_at: When the billing item was created.

          order: Field to order billing history by.

          page: Page number of paginated results.

          per_page: Number of items per page.

          type: The billing item type.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/user/billing/history",
            page=AsyncV4PagePaginationArray[BillingHistory],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "action": action,
                        "occurred_at": occurred_at,
                        "order": order,
                        "page": page,
                        "per_page": per_page,
                        "type": type,
                    },
                    history_list_params.HistoryListParams,
                ),
            ),
            model=BillingHistory,
        )


class HistoryResourceWithRawResponse:
    def __init__(self, history: HistoryResource) -> None:
        self._history = history

        self.list = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                history.list,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncHistoryResourceWithRawResponse:
    def __init__(self, history: AsyncHistoryResource) -> None:
        self._history = history

        self.list = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                history.list,  # pyright: ignore[reportDeprecated],
            )
        )


class HistoryResourceWithStreamingResponse:
    def __init__(self, history: HistoryResource) -> None:
        self._history = history

        self.list = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                history.list,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncHistoryResourceWithStreamingResponse:
    def __init__(self, history: AsyncHistoryResource) -> None:
        self._history = history

        self.list = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                history.list,  # pyright: ignore[reportDeprecated],
            )
        )
