# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import TypeAlias

__all__ = ["OriginPortParam"]

OriginPortParam: TypeAlias = Union[int, str]
