# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from ..._types import SequenceNotStr

__all__ = ["EvaluationCreateParams"]


class EvaluationCreateParams(TypedDict, total=False):
    account_id: Required[str]

    dataset_ids: Required[SequenceNotStr[str]]

    evaluation_type_ids: Required[SequenceNotStr[str]]

    name: Required[str]
