# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .user_agent_directive_params import UserAgentDirectiveParams as UserAgentDirectiveParams
from .user_agent_directive_response import UserAgentDirectiveResponse as UserAgentDirectiveResponse
