# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .dcv_method import DCVMethod as DCVMethod
from .bundle_method import BundleMethod as BundleMethod
from .domain_validation_type import DomainValidationType as DomainValidationType
from .custom_hostname_edit_params import CustomHostnameEditParams as CustomHostnameEditParams
from .custom_hostname_list_params import CustomHostnameListParams as CustomHostnameListParams
from .custom_hostname_get_response import CustomHostnameGetResponse as CustomHostnameGetResponse
from .fallback_origin_get_response import FallbackOriginGetResponse as FallbackOriginGetResponse
from .custom_hostname_create_params import CustomHostnameCreateParams as CustomHostnameCreateParams
from .custom_hostname_edit_response import CustomHostnameEditResponse as CustomHostnameEditResponse
from .custom_hostname_list_response import CustomHostnameListResponse as CustomHostnameListResponse
from .fallback_origin_update_params import FallbackOriginUpdateParams as FallbackOriginUpdateParams
from .custom_hostname_create_response import CustomHostnameCreateResponse as CustomHostnameCreateResponse
from .custom_hostname_delete_response import CustomHostnameDeleteResponse as CustomHostnameDeleteResponse
from .fallback_origin_delete_response import FallbackOriginDeleteResponse as FallbackOriginDeleteResponse
from .fallback_origin_update_response import FallbackOriginUpdateResponse as FallbackOriginUpdateResponse
