# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["RequestValidity"]

RequestValidity: TypeAlias = Literal[7, 30, 90, 365, 730, 1095, 5475]
