# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .access_request import AccessRequest

__all__ = ["AccessRequestListResponse"]

AccessRequestListResponse: TypeAlias = List[AccessRequest]
