# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from ....._types import SequenceNotStr

__all__ = ["ViewCreateParams"]


class ViewCreateParams(TypedDict, total=False):
    account_id: Required[str]
    """Identifier."""

    name: Required[str]
    """The name of the view."""

    zones: Required[SequenceNotStr[str]]
    """The list of zones linked to this view."""
