# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Optional
from datetime import datetime
from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import path_template, maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...pagination import SyncV4PagePaginationArray, AsyncV4PagePaginationArray
from ..._base_client import AsyncPaginator, make_request_options
from ...types.email_security import submission_list_params
from ...types.email_security.submission_list_response import SubmissionListResponse

__all__ = ["SubmissionsResource", "AsyncSubmissionsResource"]


class SubmissionsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SubmissionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return SubmissionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SubmissionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return SubmissionsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        account_id: str,
        end: Union[str, datetime] | Omit = omit,
        escalated_from_user: bool | Omit = omit,
        original_disposition: Literal["MALICIOUS", "SUSPICIOUS", "SPOOF", "SPAM", "BULK", "NONE"] | Omit = omit,
        outcome_disposition: Literal["MALICIOUS", "SUSPICIOUS", "SPOOF", "SPAM", "BULK", "NONE"] | Omit = omit,
        page: int | Omit = omit,
        per_page: int | Omit = omit,
        query: Optional[str] | Omit = omit,
        requested_disposition: Literal["MALICIOUS", "SUSPICIOUS", "SPOOF", "SPAM", "BULK", "NONE"] | Omit = omit,
        start: Union[str, datetime] | Omit = omit,
        status: str | Omit = omit,
        submission_id: str | Omit = omit,
        type: Literal["TEAM", "USER"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncV4PagePaginationArray[SubmissionListResponse]:
        """Returns information for submissions made to reclassify emails.

        Shows the status,
        outcome, and disposition changes for reclassification requests made by users or
        the security team. Useful for tracking false positive/negative reports.

        Args:
          account_id: Identifier.

          end: The end of the search date range. Defaults to `now`.

          escalated_from_user: When true, return only submissions that were escalated by an end user (vs. by
              the security team). When false, return only submissions that were not escalated
              by an end user. When omitted, no filter is applied.

          page: Current page within paginated list of results.

          per_page: The number of results per page. Maximum value is 1000.

          start: The beginning of the search date range. Defaults to `now - 30 days`.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/email-security/submissions", account_id=account_id),
            page=SyncV4PagePaginationArray[SubmissionListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "end": end,
                        "escalated_from_user": escalated_from_user,
                        "original_disposition": original_disposition,
                        "outcome_disposition": outcome_disposition,
                        "page": page,
                        "per_page": per_page,
                        "query": query,
                        "requested_disposition": requested_disposition,
                        "start": start,
                        "status": status,
                        "submission_id": submission_id,
                        "type": type,
                    },
                    submission_list_params.SubmissionListParams,
                ),
            ),
            model=SubmissionListResponse,
        )


class AsyncSubmissionsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSubmissionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSubmissionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSubmissionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncSubmissionsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        account_id: str,
        end: Union[str, datetime] | Omit = omit,
        escalated_from_user: bool | Omit = omit,
        original_disposition: Literal["MALICIOUS", "SUSPICIOUS", "SPOOF", "SPAM", "BULK", "NONE"] | Omit = omit,
        outcome_disposition: Literal["MALICIOUS", "SUSPICIOUS", "SPOOF", "SPAM", "BULK", "NONE"] | Omit = omit,
        page: int | Omit = omit,
        per_page: int | Omit = omit,
        query: Optional[str] | Omit = omit,
        requested_disposition: Literal["MALICIOUS", "SUSPICIOUS", "SPOOF", "SPAM", "BULK", "NONE"] | Omit = omit,
        start: Union[str, datetime] | Omit = omit,
        status: str | Omit = omit,
        submission_id: str | Omit = omit,
        type: Literal["TEAM", "USER"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[SubmissionListResponse, AsyncV4PagePaginationArray[SubmissionListResponse]]:
        """Returns information for submissions made to reclassify emails.

        Shows the status,
        outcome, and disposition changes for reclassification requests made by users or
        the security team. Useful for tracking false positive/negative reports.

        Args:
          account_id: Identifier.

          end: The end of the search date range. Defaults to `now`.

          escalated_from_user: When true, return only submissions that were escalated by an end user (vs. by
              the security team). When false, return only submissions that were not escalated
              by an end user. When omitted, no filter is applied.

          page: Current page within paginated list of results.

          per_page: The number of results per page. Maximum value is 1000.

          start: The beginning of the search date range. Defaults to `now - 30 days`.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/email-security/submissions", account_id=account_id),
            page=AsyncV4PagePaginationArray[SubmissionListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "end": end,
                        "escalated_from_user": escalated_from_user,
                        "original_disposition": original_disposition,
                        "outcome_disposition": outcome_disposition,
                        "page": page,
                        "per_page": per_page,
                        "query": query,
                        "requested_disposition": requested_disposition,
                        "start": start,
                        "status": status,
                        "submission_id": submission_id,
                        "type": type,
                    },
                    submission_list_params.SubmissionListParams,
                ),
            ),
            model=SubmissionListResponse,
        )


class SubmissionsResourceWithRawResponse:
    def __init__(self, submissions: SubmissionsResource) -> None:
        self._submissions = submissions

        self.list = to_raw_response_wrapper(
            submissions.list,
        )


class AsyncSubmissionsResourceWithRawResponse:
    def __init__(self, submissions: AsyncSubmissionsResource) -> None:
        self._submissions = submissions

        self.list = async_to_raw_response_wrapper(
            submissions.list,
        )


class SubmissionsResourceWithStreamingResponse:
    def __init__(self, submissions: SubmissionsResource) -> None:
        self._submissions = submissions

        self.list = to_streamed_response_wrapper(
            submissions.list,
        )


class AsyncSubmissionsResourceWithStreamingResponse:
    def __init__(self, submissions: AsyncSubmissionsResource) -> None:
        self._submissions = submissions

        self.list = async_to_streamed_response_wrapper(
            submissions.list,
        )
