# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["PermissionGroupListResponse", "Meta"]


class Meta(BaseModel):
    """Attributes associated to the permission group."""

    key: Optional[str] = None

    value: Optional[str] = None


class PermissionGroupListResponse(BaseModel):
    """
    A named group of permissions that map to a group of operations against resources.
    """

    id: str
    """Identifier of the permission group."""

    meta: Optional[Meta] = None
    """Attributes associated to the permission group."""

    name: Optional[str] = None
    """Name of the permission group."""
