# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["MigrationStep", "RenamedClass", "TransferredClass"]


class RenamedClass(BaseModel):
    pass


class TransferredClass(BaseModel):
    pass


class MigrationStep(BaseModel):
    pass
