# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["KeyGetResponse"]


class KeyGetResponse(BaseModel):
    id: Optional[str] = None
    """Identifier."""

    created: Optional[datetime] = None
    """The date and time a signing key was created."""

    key_id: Optional[str] = None
    """The unique identifier for the signing key."""
