# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["RetentionCreateParams"]


class RetentionCreateParams(TypedDict, total=False):
    zone_id: Required[str]
    """Identifier."""

    flag: bool
    """The log retention flag for Logpull API."""
