# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from ...._models import BaseModel

__all__ = ["CredentialCreateResponse"]


class CredentialCreateResponse(BaseModel):
    """A credential attached to API requests during scanning.

    The
    credential `value` is write-only and never returned in responses.
    """

    id: str
    """Credential identifier."""

    credential_set_id: str
    """Parent credential set identifier."""

    location: Literal["header", "cookie"]
    """Where the credential is attached in outgoing requests."""

    location_name: str
    """Name of the header or cookie where the credential is attached."""

    name: str
    """Human-readable name."""
