# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .spam_get_params import SpamGetParams as SpamGetParams
from .spoof_get_params import SpoofGetParams as SpoofGetParams
from .spam_get_response import SpamGetResponse as SpamGetResponse
from .spoof_get_response import SpoofGetResponse as SpoofGetResponse
from .malicious_get_params import MaliciousGetParams as MaliciousGetParams
from .malicious_get_response import MaliciousGetResponse as MaliciousGetResponse
