# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .dataset import Dataset

__all__ = ["DatasetArray"]

DatasetArray: TypeAlias = List[Dataset]
