# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from ..gateway_item import GatewayItem

__all__ = ["ItemListResponse"]

ItemListResponse: TypeAlias = List[GatewayItem]
