# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["CredentialCreateParams"]


class CredentialCreateParams(TypedDict, total=False):
    account_id: Required[str]
    """Identifier."""

    location: Required[Literal["header", "cookie"]]
    """Where the credential is attached in outgoing requests."""

    location_name: Required[str]
    """Name of the header or cookie where the credential is attached."""

    name: Required[str]
    """Human-readable name."""

    value: Required[str]
    """The credential value (e.g.

    API key, session token). Write-only. Never returned in responses.
    """
