# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .domain_history import DomainHistory

__all__ = ["DomainHistoryGetResponse"]

DomainHistoryGetResponse: TypeAlias = List[DomainHistory]
