# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .ip import IP

__all__ = ["IPGetResponse"]

IPGetResponse: TypeAlias = List[IP]
