# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypeAlias

from .organization_profile import OrganizationProfile

__all__ = ["Result"]

Result: TypeAlias = OrganizationProfile
