# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .request_types_response import RequestTypesResponse

__all__ = ["RequestTypes"]

RequestTypes: TypeAlias = List[RequestTypesResponse]
