# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

from ..._types import SequenceNotStr

__all__ = ["ActionParam"]


class ActionParam(TypedDict, total=False):
    """Actions pattern."""

    type: Required[Literal["drop", "forward", "worker"]]
    """Type of supported action."""

    value: SequenceNotStr[str]
