# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import typing_extensions
from typing import Any, Type, Iterable, Optional, cast
from typing_extensions import Literal, overload

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ..._utils import path_template, required_args, maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._wrappers import ResultWrapper
from ...types.dns import (
    record_edit_params,
    record_list_params,
    record_scan_params,
    record_batch_params,
    record_create_params,
    record_import_params,
    record_update_params,
    record_scan_review_params,
)
from ...pagination import SyncSinglePage, AsyncSinglePage, SyncV4PagePaginationArray, AsyncV4PagePaginationArray
from ..._base_client import AsyncPaginator, make_request_options
from ...types.dns.ttl_param import TTLParam
from ...types.dns.record_tags import RecordTags
from ...types.dns.batch_put_param import BatchPutParam
from ...types.dns.record_response import RecordResponse
from ...types.dns.batch_patch_param import BatchPatchParam
from ...types.shared.sort_direction import SortDirection
from ...types.dns.record_scan_response import RecordScanResponse
from ...types.dns.record_batch_response import RecordBatchResponse
from ...types.dns.record_delete_response import RecordDeleteResponse
from ...types.dns.record_import_response import RecordImportResponse
from ...types.dns.record_scan_review_response import RecordScanReviewResponse
from ...types.dns.record_scan_trigger_response import RecordScanTriggerResponse

__all__ = ["RecordsResource", "AsyncRecordsResource"]


class RecordsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> RecordsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return RecordsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> RecordsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return RecordsResourceWithStreamingResponse(self)

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["A"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.ARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid IPv4 address.

          private_routing: Enables private network routing to the origin.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["AAAA"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.AAAARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid IPv6 address.

          private_routing: Enables private network routing to the origin.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CNAME"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.CNAMERecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid hostname. Must not match the record's name.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["MX"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        priority: float | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.MXRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid mail server hostname.

          priority: Required for MX and URI records; ignored for other record types (but may still
              be returned by the API). Records with lower priorities are preferred. This field
              is to be deprecated in favor of the priority field within the data map.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["NS"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.NSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid name server host name.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["OPENPGPKEY"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.DNSRecordsOpenpgpkeyRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A single Base64-encoded OpenPGP Transferable Public Key (RFC 4880 Section 11.1)

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["PTR"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.PTRRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: Domain name pointing to the address.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["TXT"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.TXTRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: Text content for the record. The content must consist of quoted "character
              strings" (RFC 1035), each with a length of up to 255 bytes. Strings exceeding
              this allowed maximum length are automatically split.

              Learn more at
              <https://www.cloudflare.com/learning/dns/dns-records/dns-txt-record/>.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CAA"],
        comment: str | Omit = omit,
        data: record_create_params.CAARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.CAARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a CAA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CERT"],
        comment: str | Omit = omit,
        data: record_create_params.CERTRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.CERTRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a CERT record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["DNSKEY"],
        comment: str | Omit = omit,
        data: record_create_params.DNSKEYRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.DNSKEYRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a DNSKEY record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["DS"],
        comment: str | Omit = omit,
        data: record_create_params.DSRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.DSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a DS record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["HTTPS"],
        comment: str | Omit = omit,
        data: record_create_params.HTTPSRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.HTTPSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a HTTPS record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["LOC"],
        comment: str | Omit = omit,
        data: record_create_params.LOCRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.LOCRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a LOC record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["NAPTR"],
        comment: str | Omit = omit,
        data: record_create_params.NAPTRRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.NAPTRRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a NAPTR record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SMIMEA"],
        comment: str | Omit = omit,
        data: record_create_params.SMIMEARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.SMIMEARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SMIMEA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SRV"],
        comment: str | Omit = omit,
        data: record_create_params.SRVRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.SRVRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SRV record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SSHFP"],
        comment: str | Omit = omit,
        data: record_create_params.SSHFPRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.SSHFPRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SSHFP record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SVCB"],
        comment: str | Omit = omit,
        data: record_create_params.SVCBRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.SVCBRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SVCB record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["TLSA"],
        comment: str | Omit = omit,
        data: record_create_params.TLSARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.TLSARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a TLSA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["URI"],
        comment: str | Omit = omit,
        data: record_create_params.URIRecordData | Omit = omit,
        priority: float | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.URIRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a URI record.

          priority: Required for MX and URI records; ignored for other record types (but may still
              be returned by the API). Records with lower priorities are preferred. This field
              is to be deprecated in favor of the priority field within the data map.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["zone_id", "name", "ttl", "type"])
    def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["A"]
        | Literal["AAAA"]
        | Literal["CNAME"]
        | Literal["MX"]
        | Literal["NS"]
        | Literal["OPENPGPKEY"]
        | Literal["PTR"]
        | Literal["TXT"]
        | Literal["CAA"]
        | Literal["CERT"]
        | Literal["DNSKEY"]
        | Literal["DS"]
        | Literal["HTTPS"]
        | Literal["LOC"]
        | Literal["NAPTR"]
        | Literal["SMIMEA"]
        | Literal["SRV"]
        | Literal["SSHFP"]
        | Literal["SVCB"]
        | Literal["TLSA"]
        | Literal["URI"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.ARecordSettings
        | record_create_params.AAAARecordSettings
        | record_create_params.CNAMERecordSettings
        | record_create_params.MXRecordSettings
        | record_create_params.NSRecordSettings
        | record_create_params.DNSRecordsOpenpgpkeyRecordSettings
        | record_create_params.PTRRecordSettings
        | record_create_params.TXTRecordSettings
        | record_create_params.CAARecordSettings
        | record_create_params.CERTRecordSettings
        | record_create_params.DNSKEYRecordSettings
        | record_create_params.DSRecordSettings
        | record_create_params.HTTPSRecordSettings
        | record_create_params.LOCRecordSettings
        | record_create_params.NAPTRRecordSettings
        | record_create_params.SMIMEARecordSettings
        | record_create_params.SRVRecordSettings
        | record_create_params.SSHFPRecordSettings
        | record_create_params.SVCBRecordSettings
        | record_create_params.TLSARecordSettings
        | record_create_params.URIRecordSettings
        | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        priority: float | Omit = omit,
        data: record_create_params.CAARecordData
        | record_create_params.CERTRecordData
        | record_create_params.DNSKEYRecordData
        | record_create_params.DSRecordData
        | record_create_params.HTTPSRecordData
        | record_create_params.LOCRecordData
        | record_create_params.NAPTRRecordData
        | record_create_params.SMIMEARecordData
        | record_create_params.SRVRecordData
        | record_create_params.SSHFPRecordData
        | record_create_params.SVCBRecordData
        | record_create_params.TLSARecordData
        | record_create_params.URIRecordData
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return cast(
            Optional[RecordResponse],
            self._post(
                path_template("/zones/{zone_id}/dns_records", zone_id=zone_id),
                body=maybe_transform(
                    {
                        "name": name,
                        "ttl": ttl,
                        "type": type,
                        "comment": comment,
                        "content": content,
                        "private_routing": private_routing,
                        "proxied": proxied,
                        "settings": settings,
                        "tags": tags,
                        "priority": priority,
                        "data": data,
                    },
                    record_create_params.RecordCreateParams,
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    post_parser=ResultWrapper[Optional[RecordResponse]]._unwrapper,
                ),
                cast_to=cast(
                    Any, ResultWrapper[RecordResponse]
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["A"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.ARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid IPv4 address.

          private_routing: Enables private network routing to the origin.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["AAAA"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.AAAARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid IPv6 address.

          private_routing: Enables private network routing to the origin.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CNAME"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.CNAMERecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid hostname. Must not match the record's name.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["MX"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        priority: float | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.MXRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid mail server hostname.

          priority: Required for MX and URI records; ignored for other record types (but may still
              be returned by the API). Records with lower priorities are preferred. This field
              is to be deprecated in favor of the priority field within the data map.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["NS"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.NSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid name server host name.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["OPENPGPKEY"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.DNSRecordsOpenpgpkeyRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A single Base64-encoded OpenPGP Transferable Public Key (RFC 4880 Section 11.1)

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["PTR"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.PTRRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: Domain name pointing to the address.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["TXT"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.TXTRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: Text content for the record. The content must consist of quoted "character
              strings" (RFC 1035), each with a length of up to 255 bytes. Strings exceeding
              this allowed maximum length are automatically split.

              Learn more at
              <https://www.cloudflare.com/learning/dns/dns-records/dns-txt-record/>.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CAA"],
        comment: str | Omit = omit,
        data: record_update_params.CAARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.CAARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a CAA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CERT"],
        comment: str | Omit = omit,
        data: record_update_params.CERTRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.CERTRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a CERT record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["DNSKEY"],
        comment: str | Omit = omit,
        data: record_update_params.DNSKEYRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.DNSKEYRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a DNSKEY record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["DS"],
        comment: str | Omit = omit,
        data: record_update_params.DSRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.DSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a DS record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["HTTPS"],
        comment: str | Omit = omit,
        data: record_update_params.HTTPSRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.HTTPSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a HTTPS record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["LOC"],
        comment: str | Omit = omit,
        data: record_update_params.LOCRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.LOCRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a LOC record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["NAPTR"],
        comment: str | Omit = omit,
        data: record_update_params.NAPTRRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.NAPTRRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a NAPTR record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SMIMEA"],
        comment: str | Omit = omit,
        data: record_update_params.SMIMEARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.SMIMEARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SMIMEA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SRV"],
        comment: str | Omit = omit,
        data: record_update_params.SRVRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.SRVRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SRV record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SSHFP"],
        comment: str | Omit = omit,
        data: record_update_params.SSHFPRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.SSHFPRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SSHFP record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SVCB"],
        comment: str | Omit = omit,
        data: record_update_params.SVCBRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.SVCBRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SVCB record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["TLSA"],
        comment: str | Omit = omit,
        data: record_update_params.TLSARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.TLSARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a TLSA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["URI"],
        comment: str | Omit = omit,
        data: record_update_params.URIRecordData | Omit = omit,
        priority: float | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.URIRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a URI record.

          priority: Required for MX and URI records; ignored for other record types (but may still
              be returned by the API). Records with lower priorities are preferred. This field
              is to be deprecated in favor of the priority field within the data map.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["zone_id", "name", "ttl", "type"])
    def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["A"]
        | Literal["AAAA"]
        | Literal["CNAME"]
        | Literal["MX"]
        | Literal["NS"]
        | Literal["OPENPGPKEY"]
        | Literal["PTR"]
        | Literal["TXT"]
        | Literal["CAA"]
        | Literal["CERT"]
        | Literal["DNSKEY"]
        | Literal["DS"]
        | Literal["HTTPS"]
        | Literal["LOC"]
        | Literal["NAPTR"]
        | Literal["SMIMEA"]
        | Literal["SRV"]
        | Literal["SSHFP"]
        | Literal["SVCB"]
        | Literal["TLSA"]
        | Literal["URI"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.ARecordSettings
        | record_update_params.AAAARecordSettings
        | record_update_params.CNAMERecordSettings
        | record_update_params.MXRecordSettings
        | record_update_params.NSRecordSettings
        | record_update_params.DNSRecordsOpenpgpkeyRecordSettings
        | record_update_params.PTRRecordSettings
        | record_update_params.TXTRecordSettings
        | record_update_params.CAARecordSettings
        | record_update_params.CERTRecordSettings
        | record_update_params.DNSKEYRecordSettings
        | record_update_params.DSRecordSettings
        | record_update_params.HTTPSRecordSettings
        | record_update_params.LOCRecordSettings
        | record_update_params.NAPTRRecordSettings
        | record_update_params.SMIMEARecordSettings
        | record_update_params.SRVRecordSettings
        | record_update_params.SSHFPRecordSettings
        | record_update_params.SVCBRecordSettings
        | record_update_params.TLSARecordSettings
        | record_update_params.URIRecordSettings
        | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        priority: float | Omit = omit,
        data: record_update_params.CAARecordData
        | record_update_params.CERTRecordData
        | record_update_params.DNSKEYRecordData
        | record_update_params.DSRecordData
        | record_update_params.HTTPSRecordData
        | record_update_params.LOCRecordData
        | record_update_params.NAPTRRecordData
        | record_update_params.SMIMEARecordData
        | record_update_params.SRVRecordData
        | record_update_params.SSHFPRecordData
        | record_update_params.SVCBRecordData
        | record_update_params.TLSARecordData
        | record_update_params.URIRecordData
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        if not dns_record_id:
            raise ValueError(f"Expected a non-empty value for `dns_record_id` but received {dns_record_id!r}")
        return cast(
            Optional[RecordResponse],
            self._put(
                path_template(
                    "/zones/{zone_id}/dns_records/{dns_record_id}", zone_id=zone_id, dns_record_id=dns_record_id
                ),
                body=maybe_transform(
                    {
                        "name": name,
                        "ttl": ttl,
                        "type": type,
                        "comment": comment,
                        "content": content,
                        "private_routing": private_routing,
                        "proxied": proxied,
                        "settings": settings,
                        "tags": tags,
                        "priority": priority,
                        "data": data,
                    },
                    record_update_params.RecordUpdateParams,
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    post_parser=ResultWrapper[Optional[RecordResponse]]._unwrapper,
                ),
                cast_to=cast(
                    Any, ResultWrapper[RecordResponse]
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )

    def list(
        self,
        *,
        zone_id: str,
        comment: record_list_params.Comment | Omit = omit,
        content: record_list_params.Content | Omit = omit,
        direction: SortDirection | Omit = omit,
        match: Literal["any", "all"] | Omit = omit,
        name: record_list_params.Name | Omit = omit,
        order: Literal["type", "name", "content", "ttl", "proxied"] | Omit = omit,
        page: float | Omit = omit,
        per_page: float | Omit = omit,
        proxied: bool | Omit = omit,
        search: str | Omit = omit,
        tag: record_list_params.Tag | Omit = omit,
        tag_match: Literal["any", "all"] | Omit = omit,
        type: Literal[
            "A",
            "AAAA",
            "CAA",
            "CERT",
            "CNAME",
            "DNSKEY",
            "DS",
            "HTTPS",
            "LOC",
            "MX",
            "NAPTR",
            "NS",
            "OPENPGPKEY",
            "PTR",
            "SMIMEA",
            "SRV",
            "SSHFP",
            "SVCB",
            "TLSA",
            "TXT",
            "URI",
        ]
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncV4PagePaginationArray[RecordResponse]:
        """
        List, search, sort, and filter a zones' DNS records.

        Args:
          zone_id: Identifier.

          direction: Direction to order DNS records in.

          match: Whether to match all search requirements or at least one (any). If set to `all`,
              acts like a logical AND between filters. If set to `any`, acts like a logical OR
              instead. Note that the interaction between tag filters is controlled by the
              `tag-match` parameter instead.

          order: Field to order DNS records by.

          page: Page number of paginated results.

          per_page: Number of DNS records per page.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          search: Allows searching in multiple properties of a DNS record simultaneously. This
              parameter is intended for human users, not automation. Its exact behavior is
              intentionally left unspecified and is subject to change in the future. This
              parameter works independently of the `match` setting. For automated searches,
              please use the other available parameters.

          tag_match: Whether to match all tag search requirements or at least one (any). If set to
              `all`, acts like a logical AND between tag filters. If set to `any`, acts like a
              logical OR instead. Note that the regular `match` parameter is still used to
              combine the resulting condition with other filters that aren't related to tags.

          type: Record type.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get_api_list(
            path_template("/zones/{zone_id}/dns_records", zone_id=zone_id),
            page=SyncV4PagePaginationArray[RecordResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "comment": comment,
                        "content": content,
                        "direction": direction,
                        "match": match,
                        "name": name,
                        "order": order,
                        "page": page,
                        "per_page": per_page,
                        "proxied": proxied,
                        "search": search,
                        "tag": tag,
                        "tag_match": tag_match,
                        "type": type,
                    },
                    record_list_params.RecordListParams,
                ),
            ),
            model=cast(Any, RecordResponse),  # Union types cannot be passed in as arguments in the type system
        )

    def delete(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordDeleteResponse]:
        """
        Delete DNS Record

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        if not dns_record_id:
            raise ValueError(f"Expected a non-empty value for `dns_record_id` but received {dns_record_id!r}")
        return self._delete(
            path_template("/zones/{zone_id}/dns_records/{dns_record_id}", zone_id=zone_id, dns_record_id=dns_record_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[RecordDeleteResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[RecordDeleteResponse]], ResultWrapper[RecordDeleteResponse]),
        )

    def batch(
        self,
        *,
        zone_id: str,
        deletes: Iterable[record_batch_params.Delete] | Omit = omit,
        patches: Iterable[BatchPatchParam] | Omit = omit,
        posts: Iterable[record_batch_params.Post] | Omit = omit,
        puts: Iterable[BatchPutParam] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordBatchResponse]:
        """
        Send a Batch of DNS Record API calls to be executed together.

        Notes:

        - Although Cloudflare will execute the batched operations in a single database
          transaction, Cloudflare's distributed KV store must treat each record change
          as a single key-value pair. This means that the propagation of changes is not
          atomic. See
          [the documentation](https://developers.cloudflare.com/dns/manage-dns-records/how-to/batch-record-changes/ "Batch DNS records")
          for more information.
        - The operations you specify within the /batch request body are always executed
          in the following order:

          - Deletes
          - Patches
          - Puts
          - Posts

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._post(
            path_template("/zones/{zone_id}/dns_records/batch", zone_id=zone_id),
            body=maybe_transform(
                {
                    "deletes": deletes,
                    "patches": patches,
                    "posts": posts,
                    "puts": puts,
                },
                record_batch_params.RecordBatchParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[RecordBatchResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[RecordBatchResponse]], ResultWrapper[RecordBatchResponse]),
        )

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["A"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.ARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid IPv4 address.

          private_routing: Enables private network routing to the origin.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["AAAA"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.AAAARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid IPv6 address.

          private_routing: Enables private network routing to the origin.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CNAME"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.CNAMERecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid hostname. Must not match the record's name.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["MX"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        priority: float | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.MXRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid mail server hostname.

          priority: Required for MX and URI records; ignored for other record types (but may still
              be returned by the API). Records with lower priorities are preferred. This field
              is to be deprecated in favor of the priority field within the data map.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["NS"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.NSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid name server host name.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["OPENPGPKEY"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.DNSRecordsOpenpgpkeyRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A single Base64-encoded OpenPGP Transferable Public Key (RFC 4880 Section 11.1)

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["PTR"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.PTRRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: Domain name pointing to the address.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["TXT"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.TXTRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: Text content for the record. The content must consist of quoted "character
              strings" (RFC 1035), each with a length of up to 255 bytes. Strings exceeding
              this allowed maximum length are automatically split.

              Learn more at
              <https://www.cloudflare.com/learning/dns/dns-records/dns-txt-record/>.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CAA"],
        comment: str | Omit = omit,
        data: record_edit_params.CAARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.CAARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a CAA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CERT"],
        comment: str | Omit = omit,
        data: record_edit_params.CERTRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.CERTRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a CERT record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["DNSKEY"],
        comment: str | Omit = omit,
        data: record_edit_params.DNSKEYRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.DNSKEYRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a DNSKEY record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["DS"],
        comment: str | Omit = omit,
        data: record_edit_params.DSRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.DSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a DS record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["HTTPS"],
        comment: str | Omit = omit,
        data: record_edit_params.HTTPSRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.HTTPSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a HTTPS record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["LOC"],
        comment: str | Omit = omit,
        data: record_edit_params.LOCRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.LOCRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a LOC record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["NAPTR"],
        comment: str | Omit = omit,
        data: record_edit_params.NAPTRRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.NAPTRRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a NAPTR record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SMIMEA"],
        comment: str | Omit = omit,
        data: record_edit_params.SMIMEARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.SMIMEARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SMIMEA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SRV"],
        comment: str | Omit = omit,
        data: record_edit_params.SRVRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.SRVRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SRV record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SSHFP"],
        comment: str | Omit = omit,
        data: record_edit_params.SSHFPRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.SSHFPRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SSHFP record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SVCB"],
        comment: str | Omit = omit,
        data: record_edit_params.SVCBRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.SVCBRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SVCB record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["TLSA"],
        comment: str | Omit = omit,
        data: record_edit_params.TLSARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.TLSARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a TLSA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["URI"],
        comment: str | Omit = omit,
        data: record_edit_params.URIRecordData | Omit = omit,
        priority: float | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.URIRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a URI record.

          priority: Required for MX and URI records; ignored for other record types (but may still
              be returned by the API). Records with lower priorities are preferred. This field
              is to be deprecated in favor of the priority field within the data map.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["zone_id", "name", "ttl", "type"])
    def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["A"]
        | Literal["AAAA"]
        | Literal["CNAME"]
        | Literal["MX"]
        | Literal["NS"]
        | Literal["OPENPGPKEY"]
        | Literal["PTR"]
        | Literal["TXT"]
        | Literal["CAA"]
        | Literal["CERT"]
        | Literal["DNSKEY"]
        | Literal["DS"]
        | Literal["HTTPS"]
        | Literal["LOC"]
        | Literal["NAPTR"]
        | Literal["SMIMEA"]
        | Literal["SRV"]
        | Literal["SSHFP"]
        | Literal["SVCB"]
        | Literal["TLSA"]
        | Literal["URI"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.ARecordSettings
        | record_edit_params.AAAARecordSettings
        | record_edit_params.CNAMERecordSettings
        | record_edit_params.MXRecordSettings
        | record_edit_params.NSRecordSettings
        | record_edit_params.DNSRecordsOpenpgpkeyRecordSettings
        | record_edit_params.PTRRecordSettings
        | record_edit_params.TXTRecordSettings
        | record_edit_params.CAARecordSettings
        | record_edit_params.CERTRecordSettings
        | record_edit_params.DNSKEYRecordSettings
        | record_edit_params.DSRecordSettings
        | record_edit_params.HTTPSRecordSettings
        | record_edit_params.LOCRecordSettings
        | record_edit_params.NAPTRRecordSettings
        | record_edit_params.SMIMEARecordSettings
        | record_edit_params.SRVRecordSettings
        | record_edit_params.SSHFPRecordSettings
        | record_edit_params.SVCBRecordSettings
        | record_edit_params.TLSARecordSettings
        | record_edit_params.URIRecordSettings
        | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        priority: float | Omit = omit,
        data: record_edit_params.CAARecordData
        | record_edit_params.CERTRecordData
        | record_edit_params.DNSKEYRecordData
        | record_edit_params.DSRecordData
        | record_edit_params.HTTPSRecordData
        | record_edit_params.LOCRecordData
        | record_edit_params.NAPTRRecordData
        | record_edit_params.SMIMEARecordData
        | record_edit_params.SRVRecordData
        | record_edit_params.SSHFPRecordData
        | record_edit_params.SVCBRecordData
        | record_edit_params.TLSARecordData
        | record_edit_params.URIRecordData
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        if not dns_record_id:
            raise ValueError(f"Expected a non-empty value for `dns_record_id` but received {dns_record_id!r}")
        return cast(
            Optional[RecordResponse],
            self._patch(
                path_template(
                    "/zones/{zone_id}/dns_records/{dns_record_id}", zone_id=zone_id, dns_record_id=dns_record_id
                ),
                body=maybe_transform(
                    {
                        "name": name,
                        "ttl": ttl,
                        "type": type,
                        "comment": comment,
                        "content": content,
                        "private_routing": private_routing,
                        "proxied": proxied,
                        "settings": settings,
                        "tags": tags,
                        "priority": priority,
                        "data": data,
                    },
                    record_edit_params.RecordEditParams,
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    post_parser=ResultWrapper[Optional[RecordResponse]]._unwrapper,
                ),
                cast_to=cast(
                    Any, ResultWrapper[RecordResponse]
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )

    def export(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> str:
        """
        You can export your
        [BIND config](https://en.wikipedia.org/wiki/Zone_file "Zone file") through this
        endpoint.

        See
        [the documentation](https://developers.cloudflare.com/dns/manage-dns-records/how-to/import-and-export/ "Import and export records")
        for more information.

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return self._get(
            path_template("/zones/{zone_id}/dns_records/export", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    def get(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        DNS Record Details

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        if not dns_record_id:
            raise ValueError(f"Expected a non-empty value for `dns_record_id` but received {dns_record_id!r}")
        return cast(
            Optional[RecordResponse],
            self._get(
                path_template(
                    "/zones/{zone_id}/dns_records/{dns_record_id}", zone_id=zone_id, dns_record_id=dns_record_id
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    post_parser=ResultWrapper[Optional[RecordResponse]]._unwrapper,
                ),
                cast_to=cast(
                    Any, ResultWrapper[RecordResponse]
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )

    def import_(
        self,
        *,
        zone_id: str,
        file: str,
        proxied: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordImportResponse]:
        """
        You can upload your
        [BIND config](https://en.wikipedia.org/wiki/Zone_file "Zone file") through this
        endpoint. It assumes that cURL is called from a location with bind_config.txt
        (valid BIND config) present.

        See
        [the documentation](https://developers.cloudflare.com/dns/manage-dns-records/how-to/import-and-export/ "Import and export records")
        for more information.

        Args:
          zone_id: Identifier.

          file: BIND config to import.

              **Tip:** When using cURL, a file can be uploaded using
              `--form 'file=@bind_config.txt'`.

          proxied: Whether or not proxiable records should receive the performance and security
              benefits of Cloudflare.

              The value should be either `true` or `false`.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return self._post(
            path_template("/zones/{zone_id}/dns_records/import", zone_id=zone_id),
            body=maybe_transform(
                {
                    "file": file,
                    "proxied": proxied,
                },
                record_import_params.RecordImportParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[RecordImportResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[RecordImportResponse]], ResultWrapper[RecordImportResponse]),
        )

    @typing_extensions.deprecated(
        "This endpoint is deprecated in favor of a new asynchronous version. Please use the [/scan/trigger](https://developers.cloudflare.com/api/resources/dns/subresources/records/methods/scan/trigger) and [/scan/review](https://developers.cloudflare.com/api/resources/dns/subresources/records/methods/scan/review) endpoints instead.\n"
    )
    def scan(
        self,
        *,
        zone_id: str,
        body: object,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordScanResponse]:
        """
        Scan for common DNS records on your domain and automatically add them to your
        zone. Useful if you haven't updated your nameservers yet.

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._post(
            path_template("/zones/{zone_id}/dns_records/scan", zone_id=zone_id),
            body=maybe_transform(body, record_scan_params.RecordScanParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[RecordScanResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[RecordScanResponse]], ResultWrapper[RecordScanResponse]),
        )

    def scan_list(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncSinglePage[RecordResponse]:
        """
        Retrieves the list of DNS records discovered up to this point by the
        asynchronous scan. These records are temporary until explicitly accepted or
        rejected via `POST /scan/review`. Additional records may be discovered by the
        scan later.

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get_api_list(
            path_template("/zones/{zone_id}/dns_records/scan/review", zone_id=zone_id),
            page=SyncSinglePage[RecordResponse],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=cast(Any, RecordResponse),  # Union types cannot be passed in as arguments in the type system
        )

    def scan_review(
        self,
        *,
        zone_id: str,
        accepts: Iterable[record_scan_review_params.Accept] | Omit = omit,
        rejects: Iterable[record_scan_review_params.Reject] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordScanReviewResponse]:
        """Accept or reject DNS records found by the DNS records scan.

        Accepted records
        will be permanently added to the zone, while rejected records will be
        permanently deleted.

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._post(
            path_template("/zones/{zone_id}/dns_records/scan/review", zone_id=zone_id),
            body=maybe_transform(
                {
                    "accepts": accepts,
                    "rejects": rejects,
                },
                record_scan_review_params.RecordScanReviewParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[RecordScanReviewResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[RecordScanReviewResponse]], ResultWrapper[RecordScanReviewResponse]),
        )

    def scan_trigger(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RecordScanTriggerResponse:
        """Initiates an asynchronous scan for common DNS records on your domain.

        Note that
        this **does not** automatically add records to your zone. The scan runs in the
        background, and results can be reviewed later using the `/scan/review`
        endpoints. Useful if you haven't updated your nameservers yet.

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._post(
            path_template("/zones/{zone_id}/dns_records/scan/trigger", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RecordScanTriggerResponse,
        )


class AsyncRecordsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncRecordsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncRecordsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncRecordsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncRecordsResourceWithStreamingResponse(self)

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["A"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.ARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid IPv4 address.

          private_routing: Enables private network routing to the origin.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["AAAA"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.AAAARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid IPv6 address.

          private_routing: Enables private network routing to the origin.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CNAME"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.CNAMERecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid hostname. Must not match the record's name.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["MX"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        priority: float | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.MXRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid mail server hostname.

          priority: Required for MX and URI records; ignored for other record types (but may still
              be returned by the API). Records with lower priorities are preferred. This field
              is to be deprecated in favor of the priority field within the data map.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["NS"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.NSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid name server host name.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["OPENPGPKEY"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.DNSRecordsOpenpgpkeyRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A single Base64-encoded OpenPGP Transferable Public Key (RFC 4880 Section 11.1)

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["PTR"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.PTRRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: Domain name pointing to the address.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["TXT"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.TXTRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: Text content for the record. The content must consist of quoted "character
              strings" (RFC 1035), each with a length of up to 255 bytes. Strings exceeding
              this allowed maximum length are automatically split.

              Learn more at
              <https://www.cloudflare.com/learning/dns/dns-records/dns-txt-record/>.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CAA"],
        comment: str | Omit = omit,
        data: record_create_params.CAARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.CAARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a CAA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CERT"],
        comment: str | Omit = omit,
        data: record_create_params.CERTRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.CERTRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a CERT record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["DNSKEY"],
        comment: str | Omit = omit,
        data: record_create_params.DNSKEYRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.DNSKEYRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a DNSKEY record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["DS"],
        comment: str | Omit = omit,
        data: record_create_params.DSRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.DSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a DS record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["HTTPS"],
        comment: str | Omit = omit,
        data: record_create_params.HTTPSRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.HTTPSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a HTTPS record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["LOC"],
        comment: str | Omit = omit,
        data: record_create_params.LOCRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.LOCRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a LOC record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["NAPTR"],
        comment: str | Omit = omit,
        data: record_create_params.NAPTRRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.NAPTRRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a NAPTR record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SMIMEA"],
        comment: str | Omit = omit,
        data: record_create_params.SMIMEARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.SMIMEARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SMIMEA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SRV"],
        comment: str | Omit = omit,
        data: record_create_params.SRVRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.SRVRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SRV record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SSHFP"],
        comment: str | Omit = omit,
        data: record_create_params.SSHFPRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.SSHFPRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SSHFP record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SVCB"],
        comment: str | Omit = omit,
        data: record_create_params.SVCBRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.SVCBRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SVCB record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["TLSA"],
        comment: str | Omit = omit,
        data: record_create_params.TLSARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.TLSARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a TLSA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["URI"],
        comment: str | Omit = omit,
        data: record_create_params.URIRecordData | Omit = omit,
        priority: float | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.URIRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Create a new DNS record for a zone.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a URI record.

          priority: Required for MX and URI records; ignored for other record types (but may still
              be returned by the API). Records with lower priorities are preferred. This field
              is to be deprecated in favor of the priority field within the data map.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["zone_id", "name", "ttl", "type"])
    async def create(
        self,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["A"]
        | Literal["AAAA"]
        | Literal["CNAME"]
        | Literal["MX"]
        | Literal["NS"]
        | Literal["OPENPGPKEY"]
        | Literal["PTR"]
        | Literal["TXT"]
        | Literal["CAA"]
        | Literal["CERT"]
        | Literal["DNSKEY"]
        | Literal["DS"]
        | Literal["HTTPS"]
        | Literal["LOC"]
        | Literal["NAPTR"]
        | Literal["SMIMEA"]
        | Literal["SRV"]
        | Literal["SSHFP"]
        | Literal["SVCB"]
        | Literal["TLSA"]
        | Literal["URI"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_create_params.ARecordSettings
        | record_create_params.AAAARecordSettings
        | record_create_params.CNAMERecordSettings
        | record_create_params.MXRecordSettings
        | record_create_params.NSRecordSettings
        | record_create_params.DNSRecordsOpenpgpkeyRecordSettings
        | record_create_params.PTRRecordSettings
        | record_create_params.TXTRecordSettings
        | record_create_params.CAARecordSettings
        | record_create_params.CERTRecordSettings
        | record_create_params.DNSKEYRecordSettings
        | record_create_params.DSRecordSettings
        | record_create_params.HTTPSRecordSettings
        | record_create_params.LOCRecordSettings
        | record_create_params.NAPTRRecordSettings
        | record_create_params.SMIMEARecordSettings
        | record_create_params.SRVRecordSettings
        | record_create_params.SSHFPRecordSettings
        | record_create_params.SVCBRecordSettings
        | record_create_params.TLSARecordSettings
        | record_create_params.URIRecordSettings
        | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        priority: float | Omit = omit,
        data: record_create_params.CAARecordData
        | record_create_params.CERTRecordData
        | record_create_params.DNSKEYRecordData
        | record_create_params.DSRecordData
        | record_create_params.HTTPSRecordData
        | record_create_params.LOCRecordData
        | record_create_params.NAPTRRecordData
        | record_create_params.SMIMEARecordData
        | record_create_params.SRVRecordData
        | record_create_params.SSHFPRecordData
        | record_create_params.SVCBRecordData
        | record_create_params.TLSARecordData
        | record_create_params.URIRecordData
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return cast(
            Optional[RecordResponse],
            await self._post(
                path_template("/zones/{zone_id}/dns_records", zone_id=zone_id),
                body=await async_maybe_transform(
                    {
                        "name": name,
                        "ttl": ttl,
                        "type": type,
                        "comment": comment,
                        "content": content,
                        "private_routing": private_routing,
                        "proxied": proxied,
                        "settings": settings,
                        "tags": tags,
                        "priority": priority,
                        "data": data,
                    },
                    record_create_params.RecordCreateParams,
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    post_parser=ResultWrapper[Optional[RecordResponse]]._unwrapper,
                ),
                cast_to=cast(
                    Any, ResultWrapper[RecordResponse]
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["A"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.ARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid IPv4 address.

          private_routing: Enables private network routing to the origin.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["AAAA"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.AAAARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid IPv6 address.

          private_routing: Enables private network routing to the origin.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CNAME"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.CNAMERecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid hostname. Must not match the record's name.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["MX"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        priority: float | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.MXRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid mail server hostname.

          priority: Required for MX and URI records; ignored for other record types (but may still
              be returned by the API). Records with lower priorities are preferred. This field
              is to be deprecated in favor of the priority field within the data map.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["NS"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.NSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid name server host name.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["OPENPGPKEY"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.DNSRecordsOpenpgpkeyRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A single Base64-encoded OpenPGP Transferable Public Key (RFC 4880 Section 11.1)

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["PTR"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.PTRRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: Domain name pointing to the address.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["TXT"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.TXTRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: Text content for the record. The content must consist of quoted "character
              strings" (RFC 1035), each with a length of up to 255 bytes. Strings exceeding
              this allowed maximum length are automatically split.

              Learn more at
              <https://www.cloudflare.com/learning/dns/dns-records/dns-txt-record/>.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CAA"],
        comment: str | Omit = omit,
        data: record_update_params.CAARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.CAARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a CAA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CERT"],
        comment: str | Omit = omit,
        data: record_update_params.CERTRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.CERTRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a CERT record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["DNSKEY"],
        comment: str | Omit = omit,
        data: record_update_params.DNSKEYRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.DNSKEYRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a DNSKEY record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["DS"],
        comment: str | Omit = omit,
        data: record_update_params.DSRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.DSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a DS record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["HTTPS"],
        comment: str | Omit = omit,
        data: record_update_params.HTTPSRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.HTTPSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a HTTPS record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["LOC"],
        comment: str | Omit = omit,
        data: record_update_params.LOCRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.LOCRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a LOC record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["NAPTR"],
        comment: str | Omit = omit,
        data: record_update_params.NAPTRRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.NAPTRRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a NAPTR record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SMIMEA"],
        comment: str | Omit = omit,
        data: record_update_params.SMIMEARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.SMIMEARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SMIMEA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SRV"],
        comment: str | Omit = omit,
        data: record_update_params.SRVRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.SRVRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SRV record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SSHFP"],
        comment: str | Omit = omit,
        data: record_update_params.SSHFPRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.SSHFPRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SSHFP record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SVCB"],
        comment: str | Omit = omit,
        data: record_update_params.SVCBRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.SVCBRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SVCB record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["TLSA"],
        comment: str | Omit = omit,
        data: record_update_params.TLSARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.TLSARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a TLSA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["URI"],
        comment: str | Omit = omit,
        data: record_update_params.URIRecordData | Omit = omit,
        priority: float | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.URIRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Overwrite an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a URI record.

          priority: Required for MX and URI records; ignored for other record types (but may still
              be returned by the API). Records with lower priorities are preferred. This field
              is to be deprecated in favor of the priority field within the data map.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["zone_id", "name", "ttl", "type"])
    async def update(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["A"]
        | Literal["AAAA"]
        | Literal["CNAME"]
        | Literal["MX"]
        | Literal["NS"]
        | Literal["OPENPGPKEY"]
        | Literal["PTR"]
        | Literal["TXT"]
        | Literal["CAA"]
        | Literal["CERT"]
        | Literal["DNSKEY"]
        | Literal["DS"]
        | Literal["HTTPS"]
        | Literal["LOC"]
        | Literal["NAPTR"]
        | Literal["SMIMEA"]
        | Literal["SRV"]
        | Literal["SSHFP"]
        | Literal["SVCB"]
        | Literal["TLSA"]
        | Literal["URI"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_update_params.ARecordSettings
        | record_update_params.AAAARecordSettings
        | record_update_params.CNAMERecordSettings
        | record_update_params.MXRecordSettings
        | record_update_params.NSRecordSettings
        | record_update_params.DNSRecordsOpenpgpkeyRecordSettings
        | record_update_params.PTRRecordSettings
        | record_update_params.TXTRecordSettings
        | record_update_params.CAARecordSettings
        | record_update_params.CERTRecordSettings
        | record_update_params.DNSKEYRecordSettings
        | record_update_params.DSRecordSettings
        | record_update_params.HTTPSRecordSettings
        | record_update_params.LOCRecordSettings
        | record_update_params.NAPTRRecordSettings
        | record_update_params.SMIMEARecordSettings
        | record_update_params.SRVRecordSettings
        | record_update_params.SSHFPRecordSettings
        | record_update_params.SVCBRecordSettings
        | record_update_params.TLSARecordSettings
        | record_update_params.URIRecordSettings
        | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        priority: float | Omit = omit,
        data: record_update_params.CAARecordData
        | record_update_params.CERTRecordData
        | record_update_params.DNSKEYRecordData
        | record_update_params.DSRecordData
        | record_update_params.HTTPSRecordData
        | record_update_params.LOCRecordData
        | record_update_params.NAPTRRecordData
        | record_update_params.SMIMEARecordData
        | record_update_params.SRVRecordData
        | record_update_params.SSHFPRecordData
        | record_update_params.SVCBRecordData
        | record_update_params.TLSARecordData
        | record_update_params.URIRecordData
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        if not dns_record_id:
            raise ValueError(f"Expected a non-empty value for `dns_record_id` but received {dns_record_id!r}")
        return cast(
            Optional[RecordResponse],
            await self._put(
                path_template(
                    "/zones/{zone_id}/dns_records/{dns_record_id}", zone_id=zone_id, dns_record_id=dns_record_id
                ),
                body=await async_maybe_transform(
                    {
                        "name": name,
                        "ttl": ttl,
                        "type": type,
                        "comment": comment,
                        "content": content,
                        "private_routing": private_routing,
                        "proxied": proxied,
                        "settings": settings,
                        "tags": tags,
                        "priority": priority,
                        "data": data,
                    },
                    record_update_params.RecordUpdateParams,
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    post_parser=ResultWrapper[Optional[RecordResponse]]._unwrapper,
                ),
                cast_to=cast(
                    Any, ResultWrapper[RecordResponse]
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )

    def list(
        self,
        *,
        zone_id: str,
        comment: record_list_params.Comment | Omit = omit,
        content: record_list_params.Content | Omit = omit,
        direction: SortDirection | Omit = omit,
        match: Literal["any", "all"] | Omit = omit,
        name: record_list_params.Name | Omit = omit,
        order: Literal["type", "name", "content", "ttl", "proxied"] | Omit = omit,
        page: float | Omit = omit,
        per_page: float | Omit = omit,
        proxied: bool | Omit = omit,
        search: str | Omit = omit,
        tag: record_list_params.Tag | Omit = omit,
        tag_match: Literal["any", "all"] | Omit = omit,
        type: Literal[
            "A",
            "AAAA",
            "CAA",
            "CERT",
            "CNAME",
            "DNSKEY",
            "DS",
            "HTTPS",
            "LOC",
            "MX",
            "NAPTR",
            "NS",
            "OPENPGPKEY",
            "PTR",
            "SMIMEA",
            "SRV",
            "SSHFP",
            "SVCB",
            "TLSA",
            "TXT",
            "URI",
        ]
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[RecordResponse, AsyncV4PagePaginationArray[RecordResponse]]:
        """
        List, search, sort, and filter a zones' DNS records.

        Args:
          zone_id: Identifier.

          direction: Direction to order DNS records in.

          match: Whether to match all search requirements or at least one (any). If set to `all`,
              acts like a logical AND between filters. If set to `any`, acts like a logical OR
              instead. Note that the interaction between tag filters is controlled by the
              `tag-match` parameter instead.

          order: Field to order DNS records by.

          page: Page number of paginated results.

          per_page: Number of DNS records per page.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          search: Allows searching in multiple properties of a DNS record simultaneously. This
              parameter is intended for human users, not automation. Its exact behavior is
              intentionally left unspecified and is subject to change in the future. This
              parameter works independently of the `match` setting. For automated searches,
              please use the other available parameters.

          tag_match: Whether to match all tag search requirements or at least one (any). If set to
              `all`, acts like a logical AND between tag filters. If set to `any`, acts like a
              logical OR instead. Note that the regular `match` parameter is still used to
              combine the resulting condition with other filters that aren't related to tags.

          type: Record type.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get_api_list(
            path_template("/zones/{zone_id}/dns_records", zone_id=zone_id),
            page=AsyncV4PagePaginationArray[RecordResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "comment": comment,
                        "content": content,
                        "direction": direction,
                        "match": match,
                        "name": name,
                        "order": order,
                        "page": page,
                        "per_page": per_page,
                        "proxied": proxied,
                        "search": search,
                        "tag": tag,
                        "tag_match": tag_match,
                        "type": type,
                    },
                    record_list_params.RecordListParams,
                ),
            ),
            model=cast(Any, RecordResponse),  # Union types cannot be passed in as arguments in the type system
        )

    async def delete(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordDeleteResponse]:
        """
        Delete DNS Record

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        if not dns_record_id:
            raise ValueError(f"Expected a non-empty value for `dns_record_id` but received {dns_record_id!r}")
        return await self._delete(
            path_template("/zones/{zone_id}/dns_records/{dns_record_id}", zone_id=zone_id, dns_record_id=dns_record_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[RecordDeleteResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[RecordDeleteResponse]], ResultWrapper[RecordDeleteResponse]),
        )

    async def batch(
        self,
        *,
        zone_id: str,
        deletes: Iterable[record_batch_params.Delete] | Omit = omit,
        patches: Iterable[BatchPatchParam] | Omit = omit,
        posts: Iterable[record_batch_params.Post] | Omit = omit,
        puts: Iterable[BatchPutParam] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordBatchResponse]:
        """
        Send a Batch of DNS Record API calls to be executed together.

        Notes:

        - Although Cloudflare will execute the batched operations in a single database
          transaction, Cloudflare's distributed KV store must treat each record change
          as a single key-value pair. This means that the propagation of changes is not
          atomic. See
          [the documentation](https://developers.cloudflare.com/dns/manage-dns-records/how-to/batch-record-changes/ "Batch DNS records")
          for more information.
        - The operations you specify within the /batch request body are always executed
          in the following order:

          - Deletes
          - Patches
          - Puts
          - Posts

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._post(
            path_template("/zones/{zone_id}/dns_records/batch", zone_id=zone_id),
            body=await async_maybe_transform(
                {
                    "deletes": deletes,
                    "patches": patches,
                    "posts": posts,
                    "puts": puts,
                },
                record_batch_params.RecordBatchParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[RecordBatchResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[RecordBatchResponse]], ResultWrapper[RecordBatchResponse]),
        )

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["A"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.ARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid IPv4 address.

          private_routing: Enables private network routing to the origin.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["AAAA"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.AAAARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid IPv6 address.

          private_routing: Enables private network routing to the origin.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CNAME"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.CNAMERecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid hostname. Must not match the record's name.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["MX"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        priority: float | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.MXRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid mail server hostname.

          priority: Required for MX and URI records; ignored for other record types (but may still
              be returned by the API). Records with lower priorities are preferred. This field
              is to be deprecated in favor of the priority field within the data map.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["NS"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.NSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A valid name server host name.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["OPENPGPKEY"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.DNSRecordsOpenpgpkeyRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: A single Base64-encoded OpenPGP Transferable Public Key (RFC 4880 Section 11.1)

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["PTR"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.PTRRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: Domain name pointing to the address.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["TXT"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.TXTRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          content: Text content for the record. The content must consist of quoted "character
              strings" (RFC 1035), each with a length of up to 255 bytes. Strings exceeding
              this allowed maximum length are automatically split.

              Learn more at
              <https://www.cloudflare.com/learning/dns/dns-records/dns-txt-record/>.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CAA"],
        comment: str | Omit = omit,
        data: record_edit_params.CAARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.CAARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a CAA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["CERT"],
        comment: str | Omit = omit,
        data: record_edit_params.CERTRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.CERTRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a CERT record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["DNSKEY"],
        comment: str | Omit = omit,
        data: record_edit_params.DNSKEYRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.DNSKEYRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a DNSKEY record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["DS"],
        comment: str | Omit = omit,
        data: record_edit_params.DSRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.DSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a DS record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["HTTPS"],
        comment: str | Omit = omit,
        data: record_edit_params.HTTPSRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.HTTPSRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a HTTPS record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["LOC"],
        comment: str | Omit = omit,
        data: record_edit_params.LOCRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.LOCRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a LOC record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["NAPTR"],
        comment: str | Omit = omit,
        data: record_edit_params.NAPTRRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.NAPTRRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a NAPTR record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SMIMEA"],
        comment: str | Omit = omit,
        data: record_edit_params.SMIMEARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.SMIMEARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SMIMEA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SRV"],
        comment: str | Omit = omit,
        data: record_edit_params.SRVRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.SRVRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SRV record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SSHFP"],
        comment: str | Omit = omit,
        data: record_edit_params.SSHFPRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.SSHFPRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SSHFP record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["SVCB"],
        comment: str | Omit = omit,
        data: record_edit_params.SVCBRecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.SVCBRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a SVCB record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["TLSA"],
        comment: str | Omit = omit,
        data: record_edit_params.TLSARecordData | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.TLSARecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a TLSA record.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @overload
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["URI"],
        comment: str | Omit = omit,
        data: record_edit_params.URIRecordData | Omit = omit,
        priority: float | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.URIRecordSettings | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        Update an existing DNS record.

        Notes:

        - A/AAAA records cannot exist on the same name as CNAME records.
        - NS records cannot exist on the same name as any other record type.
        - Domain names are always represented in Punycode, even if Unicode characters
          were used when creating the record.

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          name: Complete DNS record name, including the zone name, in Punycode.

          ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 1 means 'automatic'.
              Value must be between 60 and 86400, with the minimum reduced to 30 for
              Enterprise zones.

          type: Record type.

          comment: Comments or notes about the DNS record. This field has no effect on DNS
              responses.

          data: Components of a URI record.

          priority: Required for MX and URI records; ignored for other record types (but may still
              be returned by the API). Records with lower priorities are preferred. This field
              is to be deprecated in favor of the priority field within the data map.

          proxied: Whether the record is receiving the performance and security benefits of
              Cloudflare.

          settings: Settings for the DNS record.

          tags: Custom tags for the DNS record. This field has no effect on DNS responses.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        ...

    @required_args(["zone_id", "name", "ttl", "type"])
    async def edit(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        name: str,
        ttl: TTLParam,
        type: Literal["A"]
        | Literal["AAAA"]
        | Literal["CNAME"]
        | Literal["MX"]
        | Literal["NS"]
        | Literal["OPENPGPKEY"]
        | Literal["PTR"]
        | Literal["TXT"]
        | Literal["CAA"]
        | Literal["CERT"]
        | Literal["DNSKEY"]
        | Literal["DS"]
        | Literal["HTTPS"]
        | Literal["LOC"]
        | Literal["NAPTR"]
        | Literal["SMIMEA"]
        | Literal["SRV"]
        | Literal["SSHFP"]
        | Literal["SVCB"]
        | Literal["TLSA"]
        | Literal["URI"],
        comment: str | Omit = omit,
        content: str | Omit = omit,
        private_routing: bool | Omit = omit,
        proxied: bool | Omit = omit,
        settings: record_edit_params.ARecordSettings
        | record_edit_params.AAAARecordSettings
        | record_edit_params.CNAMERecordSettings
        | record_edit_params.MXRecordSettings
        | record_edit_params.NSRecordSettings
        | record_edit_params.DNSRecordsOpenpgpkeyRecordSettings
        | record_edit_params.PTRRecordSettings
        | record_edit_params.TXTRecordSettings
        | record_edit_params.CAARecordSettings
        | record_edit_params.CERTRecordSettings
        | record_edit_params.DNSKEYRecordSettings
        | record_edit_params.DSRecordSettings
        | record_edit_params.HTTPSRecordSettings
        | record_edit_params.LOCRecordSettings
        | record_edit_params.NAPTRRecordSettings
        | record_edit_params.SMIMEARecordSettings
        | record_edit_params.SRVRecordSettings
        | record_edit_params.SSHFPRecordSettings
        | record_edit_params.SVCBRecordSettings
        | record_edit_params.TLSARecordSettings
        | record_edit_params.URIRecordSettings
        | Omit = omit,
        tags: SequenceNotStr[RecordTags] | Omit = omit,
        priority: float | Omit = omit,
        data: record_edit_params.CAARecordData
        | record_edit_params.CERTRecordData
        | record_edit_params.DNSKEYRecordData
        | record_edit_params.DSRecordData
        | record_edit_params.HTTPSRecordData
        | record_edit_params.LOCRecordData
        | record_edit_params.NAPTRRecordData
        | record_edit_params.SMIMEARecordData
        | record_edit_params.SRVRecordData
        | record_edit_params.SSHFPRecordData
        | record_edit_params.SVCBRecordData
        | record_edit_params.TLSARecordData
        | record_edit_params.URIRecordData
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        if not dns_record_id:
            raise ValueError(f"Expected a non-empty value for `dns_record_id` but received {dns_record_id!r}")
        return cast(
            Optional[RecordResponse],
            await self._patch(
                path_template(
                    "/zones/{zone_id}/dns_records/{dns_record_id}", zone_id=zone_id, dns_record_id=dns_record_id
                ),
                body=await async_maybe_transform(
                    {
                        "name": name,
                        "ttl": ttl,
                        "type": type,
                        "comment": comment,
                        "content": content,
                        "private_routing": private_routing,
                        "proxied": proxied,
                        "settings": settings,
                        "tags": tags,
                        "priority": priority,
                        "data": data,
                    },
                    record_edit_params.RecordEditParams,
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    post_parser=ResultWrapper[Optional[RecordResponse]]._unwrapper,
                ),
                cast_to=cast(
                    Any, ResultWrapper[RecordResponse]
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )

    async def export(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> str:
        """
        You can export your
        [BIND config](https://en.wikipedia.org/wiki/Zone_file "Zone file") through this
        endpoint.

        See
        [the documentation](https://developers.cloudflare.com/dns/manage-dns-records/how-to/import-and-export/ "Import and export records")
        for more information.

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return await self._get(
            path_template("/zones/{zone_id}/dns_records/export", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    async def get(
        self,
        dns_record_id: str,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordResponse]:
        """
        DNS Record Details

        Args:
          zone_id: Identifier.

          dns_record_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        if not dns_record_id:
            raise ValueError(f"Expected a non-empty value for `dns_record_id` but received {dns_record_id!r}")
        return cast(
            Optional[RecordResponse],
            await self._get(
                path_template(
                    "/zones/{zone_id}/dns_records/{dns_record_id}", zone_id=zone_id, dns_record_id=dns_record_id
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    post_parser=ResultWrapper[Optional[RecordResponse]]._unwrapper,
                ),
                cast_to=cast(
                    Any, ResultWrapper[RecordResponse]
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )

    async def import_(
        self,
        *,
        zone_id: str,
        file: str,
        proxied: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordImportResponse]:
        """
        You can upload your
        [BIND config](https://en.wikipedia.org/wiki/Zone_file "Zone file") through this
        endpoint. It assumes that cURL is called from a location with bind_config.txt
        (valid BIND config) present.

        See
        [the documentation](https://developers.cloudflare.com/dns/manage-dns-records/how-to/import-and-export/ "Import and export records")
        for more information.

        Args:
          zone_id: Identifier.

          file: BIND config to import.

              **Tip:** When using cURL, a file can be uploaded using
              `--form 'file=@bind_config.txt'`.

          proxied: Whether or not proxiable records should receive the performance and security
              benefits of Cloudflare.

              The value should be either `true` or `false`.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return await self._post(
            path_template("/zones/{zone_id}/dns_records/import", zone_id=zone_id),
            body=await async_maybe_transform(
                {
                    "file": file,
                    "proxied": proxied,
                },
                record_import_params.RecordImportParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[RecordImportResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[RecordImportResponse]], ResultWrapper[RecordImportResponse]),
        )

    @typing_extensions.deprecated(
        "This endpoint is deprecated in favor of a new asynchronous version. Please use the [/scan/trigger](https://developers.cloudflare.com/api/resources/dns/subresources/records/methods/scan/trigger) and [/scan/review](https://developers.cloudflare.com/api/resources/dns/subresources/records/methods/scan/review) endpoints instead.\n"
    )
    async def scan(
        self,
        *,
        zone_id: str,
        body: object,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordScanResponse]:
        """
        Scan for common DNS records on your domain and automatically add them to your
        zone. Useful if you haven't updated your nameservers yet.

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._post(
            path_template("/zones/{zone_id}/dns_records/scan", zone_id=zone_id),
            body=await async_maybe_transform(body, record_scan_params.RecordScanParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[RecordScanResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[RecordScanResponse]], ResultWrapper[RecordScanResponse]),
        )

    def scan_list(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[RecordResponse, AsyncSinglePage[RecordResponse]]:
        """
        Retrieves the list of DNS records discovered up to this point by the
        asynchronous scan. These records are temporary until explicitly accepted or
        rejected via `POST /scan/review`. Additional records may be discovered by the
        scan later.

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get_api_list(
            path_template("/zones/{zone_id}/dns_records/scan/review", zone_id=zone_id),
            page=AsyncSinglePage[RecordResponse],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=cast(Any, RecordResponse),  # Union types cannot be passed in as arguments in the type system
        )

    async def scan_review(
        self,
        *,
        zone_id: str,
        accepts: Iterable[record_scan_review_params.Accept] | Omit = omit,
        rejects: Iterable[record_scan_review_params.Reject] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[RecordScanReviewResponse]:
        """Accept or reject DNS records found by the DNS records scan.

        Accepted records
        will be permanently added to the zone, while rejected records will be
        permanently deleted.

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._post(
            path_template("/zones/{zone_id}/dns_records/scan/review", zone_id=zone_id),
            body=await async_maybe_transform(
                {
                    "accepts": accepts,
                    "rejects": rejects,
                },
                record_scan_review_params.RecordScanReviewParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[RecordScanReviewResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[RecordScanReviewResponse]], ResultWrapper[RecordScanReviewResponse]),
        )

    async def scan_trigger(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RecordScanTriggerResponse:
        """Initiates an asynchronous scan for common DNS records on your domain.

        Note that
        this **does not** automatically add records to your zone. The scan runs in the
        background, and results can be reviewed later using the `/scan/review`
        endpoints. Useful if you haven't updated your nameservers yet.

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._post(
            path_template("/zones/{zone_id}/dns_records/scan/trigger", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RecordScanTriggerResponse,
        )


class RecordsResourceWithRawResponse:
    def __init__(self, records: RecordsResource) -> None:
        self._records = records

        self.create = to_raw_response_wrapper(
            records.create,
        )
        self.update = to_raw_response_wrapper(
            records.update,
        )
        self.list = to_raw_response_wrapper(
            records.list,
        )
        self.delete = to_raw_response_wrapper(
            records.delete,
        )
        self.batch = to_raw_response_wrapper(
            records.batch,
        )
        self.edit = to_raw_response_wrapper(
            records.edit,
        )
        self.export = to_raw_response_wrapper(
            records.export,
        )
        self.get = to_raw_response_wrapper(
            records.get,
        )
        self.import_ = to_raw_response_wrapper(
            records.import_,
        )
        self.scan = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                records.scan,  # pyright: ignore[reportDeprecated],
            )
        )
        self.scan_list = to_raw_response_wrapper(
            records.scan_list,
        )
        self.scan_review = to_raw_response_wrapper(
            records.scan_review,
        )
        self.scan_trigger = to_raw_response_wrapper(
            records.scan_trigger,
        )


class AsyncRecordsResourceWithRawResponse:
    def __init__(self, records: AsyncRecordsResource) -> None:
        self._records = records

        self.create = async_to_raw_response_wrapper(
            records.create,
        )
        self.update = async_to_raw_response_wrapper(
            records.update,
        )
        self.list = async_to_raw_response_wrapper(
            records.list,
        )
        self.delete = async_to_raw_response_wrapper(
            records.delete,
        )
        self.batch = async_to_raw_response_wrapper(
            records.batch,
        )
        self.edit = async_to_raw_response_wrapper(
            records.edit,
        )
        self.export = async_to_raw_response_wrapper(
            records.export,
        )
        self.get = async_to_raw_response_wrapper(
            records.get,
        )
        self.import_ = async_to_raw_response_wrapper(
            records.import_,
        )
        self.scan = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                records.scan,  # pyright: ignore[reportDeprecated],
            )
        )
        self.scan_list = async_to_raw_response_wrapper(
            records.scan_list,
        )
        self.scan_review = async_to_raw_response_wrapper(
            records.scan_review,
        )
        self.scan_trigger = async_to_raw_response_wrapper(
            records.scan_trigger,
        )


class RecordsResourceWithStreamingResponse:
    def __init__(self, records: RecordsResource) -> None:
        self._records = records

        self.create = to_streamed_response_wrapper(
            records.create,
        )
        self.update = to_streamed_response_wrapper(
            records.update,
        )
        self.list = to_streamed_response_wrapper(
            records.list,
        )
        self.delete = to_streamed_response_wrapper(
            records.delete,
        )
        self.batch = to_streamed_response_wrapper(
            records.batch,
        )
        self.edit = to_streamed_response_wrapper(
            records.edit,
        )
        self.export = to_streamed_response_wrapper(
            records.export,
        )
        self.get = to_streamed_response_wrapper(
            records.get,
        )
        self.import_ = to_streamed_response_wrapper(
            records.import_,
        )
        self.scan = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                records.scan,  # pyright: ignore[reportDeprecated],
            )
        )
        self.scan_list = to_streamed_response_wrapper(
            records.scan_list,
        )
        self.scan_review = to_streamed_response_wrapper(
            records.scan_review,
        )
        self.scan_trigger = to_streamed_response_wrapper(
            records.scan_trigger,
        )


class AsyncRecordsResourceWithStreamingResponse:
    def __init__(self, records: AsyncRecordsResource) -> None:
        self._records = records

        self.create = async_to_streamed_response_wrapper(
            records.create,
        )
        self.update = async_to_streamed_response_wrapper(
            records.update,
        )
        self.list = async_to_streamed_response_wrapper(
            records.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            records.delete,
        )
        self.batch = async_to_streamed_response_wrapper(
            records.batch,
        )
        self.edit = async_to_streamed_response_wrapper(
            records.edit,
        )
        self.export = async_to_streamed_response_wrapper(
            records.export,
        )
        self.get = async_to_streamed_response_wrapper(
            records.get,
        )
        self.import_ = async_to_streamed_response_wrapper(
            records.import_,
        )
        self.scan = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                records.scan,  # pyright: ignore[reportDeprecated],
            )
        )
        self.scan_list = async_to_streamed_response_wrapper(
            records.scan_list,
        )
        self.scan_review = async_to_streamed_response_wrapper(
            records.scan_review,
        )
        self.scan_trigger = async_to_streamed_response_wrapper(
            records.scan_trigger,
        )
